# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cloudrpc.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
import device_pb2 as device__pb2
import port_pb2 as port__pb2
import interface_pb2 as interface__pb2
import route_pb2 as route__pb2
import vnic_pb2 as vnic__pb2
import underlayroute_pb2 as underlayroute__pb2
import bgp_pb2 as bgp__pb2
import nexthop_pb2 as nexthop__pb2
import mapping_pb2 as mapping__pb2
import subnet_pb2 as subnet__pb2
import tunnel_pb2 as tunnel__pb2
import vpc_pb2 as vpc__pb2
import networkpolicy_pb2 as networkpolicy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63loudrpc.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x19google/api/resource.proto\x1a\x0c\x64\x65vice.proto\x1a\nport.proto\x1a\x0finterface.proto\x1a\x0broute.proto\x1a\nvnic.proto\x1a\x13underlayroute.proto\x1a\tbgp.proto\x1a\rnexthop.proto\x1a\rmapping.proto\x1a\x0csubnet.proto\x1a\x0ctunnel.proto\x1a\tvpc.proto\x1a\x13networkpolicy.proto\"\x1e\n\x1cGetDeviceCapabilitiesRequest\"\xba\x01\n\x13\x43reateDeviceRequest\x12@\n\x06parent\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/DeviceR\x06parent\x12\x44\n\x06\x64\x65vice\x18\x02 \x01(\x0b\x32&.opi_api.network.cloud.v1alpha1.DeviceB\x04\xe2\x41\x01\x02R\x06\x64\x65vice\x12\x1b\n\tdevice_id\x18\x03 \x01(\tR\x08\x64\x65viceId\"x\n\x13\x44\x65leteDeviceRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/DeviceR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xd0\x01\n\x13UpdateDeviceRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/DeviceR\x04name\x12>\n\x06\x64\x65vice\x18\x02 \x01(\x0b\x32&.opi_api.network.cloud.v1alpha1.DeviceR\x06\x64\x65vice\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x92\x01\n\x12ListDevicesRequest\x12@\n\x06parent\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/DeviceR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"}\n\x13ListDevicesResponse\x12>\n\x06\x64\x65vice\x18\x01 \x03(\x0b\x32&.opi_api.network.cloud.v1alpha1.DeviceR\x06\x64\x65vice\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"P\n\x10GetDeviceRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/DeviceR\x04name\"\xc6\x01\n\x11UpdatePortRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1alpha1/PortR\x04name\x12\x38\n\x04port\x18\x02 \x01(\x0b\x32$.opi_api.network.cloud.v1alpha1.PortR\x04port\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x8e\x01\n\x10ListPortsRequest\x12>\n\x06parent\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1alpha1/PortR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"u\n\x11ListPortsResponse\x12\x38\n\x04port\x18\x01 \x03(\x0b\x32$.opi_api.network.cloud.v1alpha1.PortR\x04port\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"L\n\x0eGetPortRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1alpha1/PortR\x04name\"\xac\x01\n\x11\x43reateVnicRequest\x12>\n\x06parent\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1alpha1/VnicR\x06parent\x12>\n\x04vnic\x18\x02 \x01(\x0b\x32$.opi_api.network.cloud.v1alpha1.VnicB\x04\xe2\x41\x01\x02R\x04vnic\x12\x17\n\x07vnic_id\x18\x03 \x01(\tR\x06vnicId\"t\n\x11\x44\x65leteVnicRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1alpha1/VnicR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xc6\x01\n\x11UpdateVnicRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1alpha1/VnicR\x04name\x12\x38\n\x04vnic\x18\x02 \x01(\x0b\x32$.opi_api.network.cloud.v1alpha1.VnicR\x04vnic\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x8e\x01\n\x10ListVnicsRequest\x12>\n\x06parent\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1alpha1/VnicR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"u\n\x11ListVnicsResponse\x12\x38\n\x04vnic\x18\x01 \x03(\x0b\x32$.opi_api.network.cloud.v1alpha1.VnicR\x04vnic\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"L\n\x0eGetVnicRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1alpha1/VnicR\x04name\"\xcf\x01\n\x16\x43reateInterfaceRequest\x12\x43\n\x06parent\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/InterfaceR\x06parent\x12M\n\tinterface\x18\x02 \x01(\x0b\x32).opi_api.network.cloud.v1alpha1.InterfaceB\x04\xe2\x41\x01\x02R\tinterface\x12!\n\x0cinterface_id\x18\x03 \x01(\tR\x0binterfaceId\"~\n\x16\x44\x65leteInterfaceRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/InterfaceR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xdf\x01\n\x16UpdateInterfaceRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/InterfaceR\x04name\x12G\n\tinterface\x18\x02 \x01(\x0b\x32).opi_api.network.cloud.v1alpha1.InterfaceR\tinterface\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x98\x01\n\x15ListInterfacesRequest\x12\x43\n\x06parent\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/InterfaceR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x89\x01\n\x16ListInterfacesResponse\x12G\n\tinterface\x18\x01 \x03(\x0b\x32).opi_api.network.cloud.v1alpha1.InterfaceR\tinterface\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"V\n\x13GetInterfaceRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/InterfaceR\x04name\"\xd6\x01\n\x17\x43reateRouteTableRequest\x12\x44\n\x06parent\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.network.v1alpha1/RouteTableR\x06parent\x12P\n\nroutetable\x18\x02 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.RouteTableB\x04\xe2\x41\x01\x02R\nroutetable\x12#\n\rroutetable_id\x18\x03 \x01(\tR\x0croutetableId\"\x80\x01\n\x17\x44\x65leteRouteTableRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.network.v1alpha1/RouteTableR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xe4\x01\n\x17UpdateRouteTableRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.network.v1alpha1/RouteTableR\x04name\x12J\n\nroutetable\x18\x02 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.RouteTableR\nroutetable\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x9a\x01\n\x16ListRouteTablesRequest\x12\x44\n\x06parent\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.network.v1alpha1/RouteTableR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x8d\x01\n\x17ListRouteTablesResponse\x12J\n\nroutetable\x18\x01 \x03(\x0b\x32*.opi_api.network.cloud.v1alpha1.RouteTableR\nroutetable\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"X\n\x14GetRouteTableRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.network.v1alpha1/RouteTableR\x04name\"\xb3\x01\n\x12\x43reateRouteRequest\x12?\n\x06parent\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1eopi_api.network.v1alpha1/RouteR\x06parent\x12\x41\n\x05route\x18\x02 \x01(\x0b\x32%.opi_api.network.cloud.v1alpha1.RouteB\x04\xe2\x41\x01\x02R\x05route\x12\x19\n\x08route_id\x18\x03 \x01(\tR\x07routeId\"v\n\x12\x44\x65leteRouteRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1eopi_api.network.v1alpha1/RouteR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xcb\x01\n\x12UpdateRouteRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1eopi_api.network.v1alpha1/RouteR\x04name\x12;\n\x05route\x18\x02 \x01(\x0b\x32%.opi_api.network.cloud.v1alpha1.RouteR\x05route\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x90\x01\n\x11ListRoutesRequest\x12?\n\x06parent\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1eopi_api.network.v1alpha1/RouteR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"y\n\x12ListRoutesResponse\x12;\n\x05route\x18\x01 \x03(\x0b\x32%.opi_api.network.cloud.v1alpha1.RouteR\x05route\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"N\n\x0fGetRouteRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1eopi_api.network.v1alpha1/RouteR\x04name\"\xeb\x01\n\x1a\x43reateUnderlayRouteRequest\x12G\n\x06parent\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\n&opi_api.network.v1alpha1/UnderlayRouteR\x06parent\x12Y\n\runderlayroute\x18\x02 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.UnderlayRouteB\x04\xe2\x41\x01\x02R\runderlayroute\x12)\n\x10underlayroute_id\x18\x03 \x01(\tR\x0funderlayrouteId\"\x86\x01\n\x1a\x44\x65leteUnderlayRouteRequest\x12\x43\n\x04name\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\n&opi_api.network.v1alpha1/UnderlayRouteR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xf3\x01\n\x1aUpdateUnderlayRouteRequest\x12\x43\n\x04name\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\n&opi_api.network.v1alpha1/UnderlayRouteR\x04name\x12S\n\runderlayroute\x18\x02 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.UnderlayRouteR\runderlayroute\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\xa0\x01\n\x19ListUnderlayRoutesRequest\x12G\n\x06parent\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\n&opi_api.network.v1alpha1/UnderlayRouteR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x99\x01\n\x1aListUnderlayRoutesResponse\x12S\n\runderlayroute\x18\x01 \x03(\x0b\x32-.opi_api.network.cloud.v1alpha1.UnderlayRouteR\runderlayroute\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"^\n\x17GetUnderlayRouteRequest\x12\x43\n\x04name\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\n&opi_api.network.v1alpha1/UnderlayRouteR\x04name\"\xa5\x01\n\x10\x43reateBgpRequest\x12=\n\x06parent\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/BgpR\x06parent\x12;\n\x03\x62gp\x18\x02 \x01(\x0b\x32#.opi_api.network.cloud.v1alpha1.BgpB\x04\xe2\x41\x01\x02R\x03\x62gp\x12\x15\n\x06\x62gp_id\x18\x03 \x01(\tR\x05\x62gpId\"r\n\x10\x44\x65leteBgpRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/BgpR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xc1\x01\n\x10UpdateBgpRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/BgpR\x04name\x12\x35\n\x03\x62gp\x18\x02 \x01(\x0b\x32#.opi_api.network.cloud.v1alpha1.BgpR\x03\x62gp\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x8c\x01\n\x0fListBgpsRequest\x12=\n\x06parent\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/BgpR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"q\n\x10ListBgpsResponse\x12\x35\n\x03\x62gp\x18\x01 \x03(\x0b\x32#.opi_api.network.cloud.v1alpha1.BgpR\x03\x62gp\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"J\n\rGetBgpRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/BgpR\x04name\"\xc1\x01\n\x14\x43reateBGPPeerRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/BGPPeerR\x06parent\x12G\n\x07\x62gppeer\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.BGPPeerB\x04\xe2\x41\x01\x02R\x07\x62gppeer\x12\x1d\n\nbgppeer_id\x18\x03 \x01(\tR\tbgppeerId\"z\n\x14\x44\x65leteBGPPeerRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/BGPPeerR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xd5\x01\n\x14UpdateBGPPeerRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/BGPPeerR\x04name\x12\x41\n\x07\x62gppeer\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.BGPPeerR\x07\x62gppeer\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x94\x01\n\x13ListBGPPeersRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/BGPPeerR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x81\x01\n\x14ListBGPPeersResponse\x12\x41\n\x07\x62gppeer\x18\x01 \x03(\x0b\x32\'.opi_api.network.cloud.v1alpha1.BGPPeerR\x07\x62gppeer\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"R\n\x11GetBGPPeerRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/BGPPeerR\x04name\"\xcf\x01\n\x16\x43reateBGPPeerAfRequest\x12\x43\n\x06parent\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/BGPPeerAfR\x06parent\x12M\n\tbgppeeraf\x18\x02 \x01(\x0b\x32).opi_api.network.cloud.v1alpha1.BGPPeerAfB\x04\xe2\x41\x01\x02R\tbgppeeraf\x12!\n\x0c\x62gppeeraf_id\x18\x03 \x01(\tR\x0b\x62gppeerafId\"~\n\x16\x44\x65leteBGPPeerAfRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/BGPPeerAfR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xdf\x01\n\x16UpdateBGPPeerAfRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/BGPPeerAfR\x04name\x12G\n\tbgppeeraf\x18\x02 \x01(\x0b\x32).opi_api.network.cloud.v1alpha1.BGPPeerAfR\tbgppeeraf\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x98\x01\n\x15ListBGPPeerAfsRequest\x12\x43\n\x06parent\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/BGPPeerAfR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x89\x01\n\x16ListBGPPeerAfsResponse\x12G\n\tbgppeeraf\x18\x01 \x03(\x0b\x32).opi_api.network.cloud.v1alpha1.BGPPeerAfR\tbgppeeraf\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"V\n\x13GetBGPPeerAfRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.network.v1alpha1/BGPPeerAfR\x04name\"\xc1\x01\n\x14\x43reateMappingRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/MappingR\x06parent\x12G\n\x07mapping\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.MappingB\x04\xe2\x41\x01\x02R\x07mapping\x12\x1d\n\nmapping_id\x18\x03 \x01(\tR\tmappingId\"z\n\x14\x44\x65leteMappingRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/MappingR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xd5\x01\n\x14UpdateMappingRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/MappingR\x04name\x12\x41\n\x07mapping\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.MappingR\x07mapping\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x94\x01\n\x13ListMappingsRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/MappingR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x81\x01\n\x14ListMappingsResponse\x12\x41\n\x07mapping\x18\x01 \x03(\x0b\x32\'.opi_api.network.cloud.v1alpha1.MappingR\x07mapping\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"R\n\x11GetMappingRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/MappingR\x04name\"\xc1\x01\n\x14\x43reateNextHopRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/NextHopR\x06parent\x12G\n\x07nexthop\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.NextHopB\x04\xe2\x41\x01\x02R\x07nexthop\x12\x1d\n\nnexthop_id\x18\x03 \x01(\tR\tnexthopId\"z\n\x14\x44\x65leteNextHopRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/NextHopR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xd5\x01\n\x14UpdateNextHopRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/NextHopR\x04name\x12\x41\n\x07nexthop\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.NextHopR\x07nexthop\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x93\x01\n\x12ListNextHopRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/NextHopR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x81\x01\n\x14ListNextHopsResponse\x12\x41\n\x07nexthop\x18\x01 \x03(\x0b\x32\'.opi_api.network.cloud.v1alpha1.NextHopR\x07nexthop\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"R\n\x11GetNextHopRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/NextHopR\x04name\"\xe4\x01\n\x19\x43reateNextHopGroupRequest\x12\x46\n\x06parent\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/NextHopGroupR\x06parent\x12V\n\x0cnexthopgroup\x18\x02 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.NextHopGroupB\x04\xe2\x41\x01\x02R\x0cnexthopgroup\x12\'\n\x0fnexthopgroup_id\x18\x03 \x01(\tR\x0enexthopgroupId\"\x84\x01\n\x19\x44\x65leteNextHopGroupRequest\x12\x42\n\x04name\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/NextHopGroupR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xee\x01\n\x19UpdateNextHopGroupRequest\x12\x42\n\x04name\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/NextHopGroupR\x04name\x12P\n\x0cnexthopgroup\x18\x02 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.NextHopGroupR\x0cnexthopgroup\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x9e\x01\n\x18ListNextHopGroupsRequest\x12\x46\n\x06parent\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/NextHopGroupR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x95\x01\n\x19ListNextHopGroupsResponse\x12P\n\x0cnexthopgroup\x18\x01 \x03(\x0b\x32,.opi_api.network.cloud.v1alpha1.NextHopGroupR\x0cnexthopgroup\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\\\n\x16GetNextHopGroupRequest\x12\x42\n\x04name\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/NextHopGroupR\x04name\"\xba\x01\n\x13\x43reateSubnetRequest\x12@\n\x06parent\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/SubnetR\x06parent\x12\x44\n\x06subnet\x18\x02 \x01(\x0b\x32&.opi_api.network.cloud.v1alpha1.SubnetB\x04\xe2\x41\x01\x02R\x06subnet\x12\x1b\n\tsubnet_id\x18\x03 \x01(\tR\x08subnetId\"x\n\x13\x44\x65leteSubnetRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/SubnetR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xd0\x01\n\x13UpdateSubnetRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/SubnetR\x04name\x12>\n\x06subnet\x18\x02 \x01(\x0b\x32&.opi_api.network.cloud.v1alpha1.SubnetR\x06subnet\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x92\x01\n\x12ListSubnetsRequest\x12@\n\x06parent\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/SubnetR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"}\n\x13ListSubnetsResponse\x12>\n\x06subnet\x18\x01 \x03(\x0b\x32&.opi_api.network.cloud.v1alpha1.SubnetR\x06subnet\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"P\n\x10GetSubnetRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/SubnetR\x04name\"\xba\x01\n\x13\x43reateTunnelRequest\x12@\n\x06parent\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/TunnelR\x06parent\x12\x44\n\x06tunnel\x18\x02 \x01(\x0b\x32&.opi_api.network.cloud.v1alpha1.TunnelB\x04\xe2\x41\x01\x02R\x06tunnel\x12\x1b\n\ttunnel_id\x18\x03 \x01(\tR\x08tunnelId\"x\n\x13\x44\x65leteTunnelRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/TunnelR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xd0\x01\n\x13UpdateTunnelRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/TunnelR\x04name\x12>\n\x06tunnel\x18\x02 \x01(\x0b\x32&.opi_api.network.cloud.v1alpha1.TunnelR\x06tunnel\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x92\x01\n\x12ListTunnelsRequest\x12@\n\x06parent\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/TunnelR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"}\n\x13ListTunnelsResponse\x12>\n\x06tunnel\x18\x01 \x03(\x0b\x32&.opi_api.network.cloud.v1alpha1.TunnelR\x06tunnel\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"P\n\x10GetTunnelRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.network.v1alpha1/TunnelR\x04name\"\xa5\x01\n\x10\x43reateVpcRequest\x12=\n\x06parent\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/VpcR\x06parent\x12;\n\x03vpc\x18\x02 \x01(\x0b\x32#.opi_api.network.cloud.v1alpha1.VpcB\x04\xe2\x41\x01\x02R\x03vpc\x12\x15\n\x06vpc_id\x18\x03 \x01(\tR\x05vpcId\"r\n\x10\x44\x65leteVpcRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/VpcR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xc1\x01\n\x10UpdateVpcRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/VpcR\x04name\x12\x35\n\x03vpc\x18\x02 \x01(\x0b\x32#.opi_api.network.cloud.v1alpha1.VpcR\x03vpc\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x8c\x01\n\x0fListVpcsRequest\x12=\n\x06parent\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/VpcR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"q\n\x10ListVpcsResponse\x12\x35\n\x03vpc\x18\x01 \x03(\x0b\x32#.opi_api.network.cloud.v1alpha1.VpcR\x03vpc\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"J\n\rGetVpcRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.network.v1alpha1/VpcR\x04name\"\xc1\x01\n\x14\x43reateVPCPeerRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/VPCPeerR\x06parent\x12G\n\x07vpcpeer\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.VPCPeerB\x04\xe2\x41\x01\x02R\x07vpcpeer\x12\x1d\n\nvpcpeer_id\x18\x03 \x01(\tR\tvpcpeerId\"z\n\x14\x44\x65leteVPCPeerRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/VPCPeerR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xd5\x01\n\x14UpdateVPCPeerRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/VPCPeerR\x04name\x12\x41\n\x07vpcpeer\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.VPCPeerR\x07vpcpeer\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x94\x01\n\x13ListVPCPeersRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/VPCPeerR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x81\x01\n\x14ListVPCPeersResponse\x12\x41\n\x07vpcpeer\x18\x01 \x03(\x0b\x32\'.opi_api.network.cloud.v1alpha1.VPCPeerR\x07vpcpeer\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"R\n\x11GetVPCPeerRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.network.v1alpha1/VPCPeerR\x04name\"\xf2\x01\n\x1b\x43reateSecurityPolicyRequest\x12H\n\x06parent\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.network.v1alpha1/SecurityPolicyR\x06parent\x12\\\n\x0esecuritypolicy\x18\x02 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.SecurityPolicyB\x04\xe2\x41\x01\x02R\x0esecuritypolicy\x12+\n\x11securitypolicy_id\x18\x03 \x01(\tR\x10securitypolicyId\"\x88\x01\n\x1b\x44\x65leteSecurityPolicyRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.network.v1alpha1/SecurityPolicyR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xf8\x01\n\x1bUpdateSecurityPolicyRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.network.v1alpha1/SecurityPolicyR\x04name\x12V\n\x0esecuritypolicy\x18\x02 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.SecurityPolicyR\x0esecuritypolicy\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\xa2\x01\n\x1aListSecurityPolicysRequest\x12H\n\x06parent\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.network.v1alpha1/SecurityPolicyR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x9d\x01\n\x1bListSecurityPolicysResponse\x12V\n\x0esecuritypolicy\x18\x01 \x03(\x0b\x32..opi_api.network.cloud.v1alpha1.SecurityPolicyR\x0esecuritypolicy\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"`\n\x18GetSecurityPolicyRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.network.v1alpha1/SecurityPolicyR\x04name\"\xe4\x01\n\x19\x43reateSecurityRuleRequest\x12\x46\n\x06parent\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/SecurityRuleR\x06parent\x12V\n\x0csecurityrule\x18\x02 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.SecurityRuleB\x04\xe2\x41\x01\x02R\x0csecurityrule\x12\'\n\x0fsecurityrule_id\x18\x03 \x01(\tR\x0esecurityruleId\"\x84\x01\n\x19\x44\x65leteSecurityRuleRequest\x12\x42\n\x04name\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/SecurityRuleR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xee\x01\n\x19UpdateSecurityRuleRequest\x12\x42\n\x04name\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/SecurityRuleR\x04name\x12P\n\x0csecurityrule\x18\x02 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.SecurityRuleR\x0csecurityrule\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\x9e\x01\n\x18ListSecurityRulesRequest\x12\x46\n\x06parent\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/SecurityRuleR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x95\x01\n\x19ListSecurityRulesResponse\x12P\n\x0csecurityrule\x18\x01 \x03(\x0b\x32,.opi_api.network.cloud.v1alpha1.SecurityRuleR\x0csecurityrule\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\\\n\x16GetSecurityRuleRequest\x12\x42\n\x04name\x18\x01 \x01(\tB.\xe2\x41\x01\x02\xfa\x41\'\n%opi_api.network.v1alpha1/SecurityRuleR\x04name\"\xf9\x01\n\x1c\x43reateSecurityProfileRequest\x12I\n\x06parent\x18\x01 \x01(\tB1\xe2\x41\x01\x02\xfa\x41*\n(opi_api.network.v1alpha1/SecurityProfileR\x06parent\x12_\n\x0fsecurityprofile\x18\x02 \x01(\x0b\x32/.opi_api.network.cloud.v1alpha1.SecurityProfileB\x04\xe2\x41\x01\x02R\x0fsecurityprofile\x12-\n\x12securityprofile_id\x18\x03 \x01(\tR\x11securityprofileId\"\x8a\x01\n\x1c\x44\x65leteSecurityProfileRequest\x12\x45\n\x04name\x18\x01 \x01(\tB1\xe2\x41\x01\x02\xfa\x41*\n(opi_api.network.v1alpha1/SecurityProfileR\x04name\x12#\n\rallow_missing\x18\x02 \x01(\x08R\x0c\x61llowMissing\"\xfd\x01\n\x1cUpdateSecurityProfileRequest\x12\x45\n\x04name\x18\x01 \x01(\tB1\xe2\x41\x01\x02\xfa\x41*\n(opi_api.network.v1alpha1/SecurityProfileR\x04name\x12Y\n\x0fsecurityprofile\x18\x02 \x01(\x0b\x32/.opi_api.network.cloud.v1alpha1.SecurityProfileR\x0fsecurityprofile\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\"\xa4\x01\n\x1bListSecurityProfilesRequest\x12I\n\x06parent\x18\x01 \x01(\tB1\xe2\x41\x01\x02\xfa\x41*\n(opi_api.network.v1alpha1/SecurityProfileR\x06parent\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xa1\x01\n\x1cListSecurityProfilesResponse\x12Y\n\x0fsecurityprofile\x18\x01 \x03(\x0b\x32/.opi_api.network.cloud.v1alpha1.SecurityProfileR\x0fsecurityprofile\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"b\n\x19GetSecurityProfileRequest\x12\x45\n\x04name\x18\x01 \x01(\tB1\xe2\x41\x01\x02\xfa\x41*\n(opi_api.network.v1alpha1/SecurityProfileR\x04name2\x8a{\n\x11\x43loudInfraService\x12\xad\x01\n\x15GetDeviceCapabilities\x12<.opi_api.network.cloud.v1alpha1.GetDeviceCapabilitiesRequest\x1a\x32.opi_api.network.cloud.v1alpha1.DeviceCapabilities\"\"\xda\x41\x00\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/devicecapabilitiess\x12\x9b\x01\n\x0c\x43reateDevice\x12\x33.opi_api.network.cloud.v1alpha1.CreateDeviceRequest\x1a&.opi_api.network.cloud.v1alpha1.Device\".\xda\x41\x10\x64\x65vice,device_id\x82\xd3\xe4\x93\x02\x15\"\x0b/v1/devices:\x06\x64\x65vice\x12\x80\x01\n\x0c\x44\x65leteDevice\x12\x33.opi_api.network.cloud.v1alpha1.DeleteDeviceRequest\x1a\x16.google.protobuf.Empty\"#\xda\x41\x04name\x82\xd3\xe4\x93\x02\x16*\x14/v1/{name=devices}/*\x12\xa7\x01\n\x0cUpdateDevice\x12\x33.opi_api.network.cloud.v1alpha1.UpdateDeviceRequest\x1a&.opi_api.network.cloud.v1alpha1.Device\":\xda\x41\x13\x64\x65vice, update_mask\x82\xd3\xe4\x93\x02\x1e\x32\x14/v1/{name=devices}/*:\x06\x64\x65vice\x12\x8e\x01\n\x0bListDevices\x12\x32.opi_api.network.cloud.v1alpha1.ListDevicesRequest\x1a\x33.opi_api.network.cloud.v1alpha1.ListDevicesResponse\"\x16\xda\x41\x00\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/devices\x12\x8a\x01\n\tGetDevice\x12\x30.opi_api.network.cloud.v1alpha1.GetDeviceRequest\x1a&.opi_api.network.cloud.v1alpha1.Device\"#\xda\x41\x04name\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/{name=devices}/*\x12\x9b\x01\n\nUpdatePort\x12\x31.opi_api.network.cloud.v1alpha1.UpdatePortRequest\x1a$.opi_api.network.cloud.v1alpha1.Port\"4\xda\x41\x11port, update_mask\x82\xd3\xe4\x93\x02\x1a\x32\x12/v1/{name=ports}/*:\x04port\x12\x86\x01\n\tListPorts\x12\x30.opi_api.network.cloud.v1alpha1.ListPortsRequest\x1a\x31.opi_api.network.cloud.v1alpha1.ListPortsResponse\"\x14\xda\x41\x00\x82\xd3\xe4\x93\x02\x0b\x12\t/v1/ports\x12\x82\x01\n\x07GetPort\x12..opi_api.network.cloud.v1alpha1.GetPortRequest\x1a$.opi_api.network.cloud.v1alpha1.Port\"!\xda\x41\x04name\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/{name=ports}/*\x12\x8d\x01\n\nCreateVnic\x12\x31.opi_api.network.cloud.v1alpha1.CreateVnicRequest\x1a$.opi_api.network.cloud.v1alpha1.Vnic\"&\xda\x41\x0cvnic,vnic_id\x82\xd3\xe4\x93\x02\x11\"\t/v1/vnics:\x04vnic\x12z\n\nDeleteVnic\x12\x31.opi_api.network.cloud.v1alpha1.DeleteVnicRequest\x1a\x16.google.protobuf.Empty\"!\xda\x41\x04name\x82\xd3\xe4\x93\x02\x14*\x12/v1/{name=vnics}/*\x12\x9b\x01\n\nUpdateVnic\x12\x31.opi_api.network.cloud.v1alpha1.UpdateVnicRequest\x1a$.opi_api.network.cloud.v1alpha1.Vnic\"4\xda\x41\x11vnic, update_mask\x82\xd3\xe4\x93\x02\x1a\x32\x12/v1/{name=vnics}/*:\x04vnic\x12\x86\x01\n\tListVnics\x12\x30.opi_api.network.cloud.v1alpha1.ListVnicsRequest\x1a\x31.opi_api.network.cloud.v1alpha1.ListVnicsResponse\"\x14\xda\x41\x00\x82\xd3\xe4\x93\x02\x0b\x12\t/v1/vnics\x12\x82\x01\n\x07GetVnic\x12..opi_api.network.cloud.v1alpha1.GetVnicRequest\x1a$.opi_api.network.cloud.v1alpha1.Vnic\"!\xda\x41\x04name\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/{name=vnics}/*\x12\xb0\x01\n\x0f\x43reateInterface\x12\x36.opi_api.network.cloud.v1alpha1.CreateInterfaceRequest\x1a).opi_api.network.cloud.v1alpha1.Interface\":\xda\x41\x16interface,interface_id\x82\xd3\xe4\x93\x02\x1b\"\x0e/v1/interfaces:\tinterface\x12\x89\x01\n\x0f\x44\x65leteInterface\x12\x36.opi_api.network.cloud.v1alpha1.DeleteInterfaceRequest\x1a\x16.google.protobuf.Empty\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19*\x17/v1/{name=interfaces}/*\x12\xb9\x01\n\x0fUpdateInterface\x12\x36.opi_api.network.cloud.v1alpha1.UpdateInterfaceRequest\x1a).opi_api.network.cloud.v1alpha1.Interface\"C\xda\x41\x16interface, update_mask\x82\xd3\xe4\x93\x02$2\x17/v1/{name=interfaces}/*:\tinterface\x12\x9a\x01\n\x0eListInterfaces\x12\x35.opi_api.network.cloud.v1alpha1.ListInterfacesRequest\x1a\x36.opi_api.network.cloud.v1alpha1.ListInterfacesResponse\"\x19\xda\x41\x00\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/interfaces\x12\x96\x01\n\x0cGetInterface\x12\x33.opi_api.network.cloud.v1alpha1.GetInterfaceRequest\x1a).opi_api.network.cloud.v1alpha1.Interface\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{name=interfaces}/*\x12\xb7\x01\n\x10\x43reateRouteTable\x12\x37.opi_api.network.cloud.v1alpha1.CreateRouteTableRequest\x1a*.opi_api.network.cloud.v1alpha1.RouteTable\">\xda\x41\x18routetable,routetable_id\x82\xd3\xe4\x93\x02\x1d\"\x0f/v1/routetables:\nroutetable\x12\x8c\x01\n\x10\x44\x65leteRouteTable\x12\x37.opi_api.network.cloud.v1alpha1.DeleteRouteTableRequest\x1a\x16.google.protobuf.Empty\"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a*\x18/v1/{name=routetables}/*\x12\xbf\x01\n\x10UpdateRouteTable\x12\x37.opi_api.network.cloud.v1alpha1.UpdateRouteTableRequest\x1a*.opi_api.network.cloud.v1alpha1.RouteTable\"F\xda\x41\x17routetable, update_mask\x82\xd3\xe4\x93\x02&2\x18/v1/{name=routetables}/*:\nroutetable\x12\x9e\x01\n\x0fListRouteTables\x12\x36.opi_api.network.cloud.v1alpha1.ListRouteTablesRequest\x1a\x37.opi_api.network.cloud.v1alpha1.ListRouteTablesResponse\"\x1a\xda\x41\x00\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/routetables\x12\x9a\x01\n\rGetRouteTable\x12\x34.opi_api.network.cloud.v1alpha1.GetRouteTableRequest\x1a*.opi_api.network.cloud.v1alpha1.RouteTable\"\'\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/{name=routetables}/*\x12\x94\x01\n\x0b\x43reateRoute\x12\x32.opi_api.network.cloud.v1alpha1.CreateRouteRequest\x1a%.opi_api.network.cloud.v1alpha1.Route\"*\xda\x41\x0eroute,route_id\x82\xd3\xe4\x93\x02\x13\"\n/v1/routes:\x05route\x12}\n\x0b\x44\x65leteRoute\x12\x32.opi_api.network.cloud.v1alpha1.DeleteRouteRequest\x1a\x16.google.protobuf.Empty\"\"\xda\x41\x04name\x82\xd3\xe4\x93\x02\x15*\x13/v1/{name=routes}/*\x12\xa1\x01\n\x0bUpdateRoute\x12\x32.opi_api.network.cloud.v1alpha1.UpdateRouteRequest\x1a%.opi_api.network.cloud.v1alpha1.Route\"7\xda\x41\x12route, update_mask\x82\xd3\xe4\x93\x02\x1c\x32\x13/v1/{name=routes}/*:\x05route\x12\x8a\x01\n\nListRoutes\x12\x31.opi_api.network.cloud.v1alpha1.ListRoutesRequest\x1a\x32.opi_api.network.cloud.v1alpha1.ListRoutesResponse\"\x15\xda\x41\x00\x82\xd3\xe4\x93\x02\x0c\x12\n/v1/routes\x12\x86\x01\n\x08GetRoute\x12/.opi_api.network.cloud.v1alpha1.GetRouteRequest\x1a%.opi_api.network.cloud.v1alpha1.Route\"\"\xda\x41\x04name\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/{name=routes}/*\x12\xcc\x01\n\x13\x43reateUnderlayRoute\x12:.opi_api.network.cloud.v1alpha1.CreateUnderlayRouteRequest\x1a-.opi_api.network.cloud.v1alpha1.UnderlayRoute\"J\xda\x41\x1eunderlayroute,underlayroute_id\x82\xd3\xe4\x93\x02#\"\x12/v1/underlayroutes:\runderlayroute\x12\x95\x01\n\x13\x44\x65leteUnderlayRoute\x12:.opi_api.network.cloud.v1alpha1.DeleteUnderlayRouteRequest\x1a\x16.google.protobuf.Empty\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/{name=underlayroutes}/*\x12\xd1\x01\n\x13UpdateUnderlayRoute\x12:.opi_api.network.cloud.v1alpha1.UpdateUnderlayRouteRequest\x1a-.opi_api.network.cloud.v1alpha1.UnderlayRoute\"O\xda\x41\x1aunderlayroute, update_mask\x82\xd3\xe4\x93\x02,2\x1b/v1/{name=underlayroutes}/*:\runderlayroute\x12\xaa\x01\n\x12ListUnderlayRoutes\x12\x39.opi_api.network.cloud.v1alpha1.ListUnderlayRoutesRequest\x1a:.opi_api.network.cloud.v1alpha1.ListUnderlayRoutesResponse\"\x1d\xda\x41\x00\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/underlayroutes\x12\xa6\x01\n\x10GetUnderlayRoute\x12\x37.opi_api.network.cloud.v1alpha1.GetUnderlayRouteRequest\x1a-.opi_api.network.cloud.v1alpha1.UnderlayRoute\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/{name=underlayroutes}/*\x12\x86\x01\n\tCreateBgp\x12\x30.opi_api.network.cloud.v1alpha1.CreateBgpRequest\x1a#.opi_api.network.cloud.v1alpha1.Bgp\"\"\xda\x41\nbgp,bgp_id\x82\xd3\xe4\x93\x02\x0f\"\x08/v1/bgps:\x03\x62gp\x12w\n\tDeleteBgp\x12\x30.opi_api.network.cloud.v1alpha1.DeleteBgpRequest\x1a\x16.google.protobuf.Empty\" \xda\x41\x04name\x82\xd3\xe4\x93\x02\x13*\x11/v1/{name=bgps}/*\x12\x95\x01\n\tUpdateBgp\x12\x30.opi_api.network.cloud.v1alpha1.UpdateBgpRequest\x1a#.opi_api.network.cloud.v1alpha1.Bgp\"1\xda\x41\x10\x62gp, update_mask\x82\xd3\xe4\x93\x02\x18\x32\x11/v1/{name=bgps}/*:\x03\x62gp\x12\x82\x01\n\x08ListBgps\x12/.opi_api.network.cloud.v1alpha1.ListBgpsRequest\x1a\x30.opi_api.network.cloud.v1alpha1.ListBgpsResponse\"\x13\xda\x41\x00\x82\xd3\xe4\x93\x02\n\x12\x08/v1/bgps\x12~\n\x06GetBgp\x12-.opi_api.network.cloud.v1alpha1.GetBgpRequest\x1a#.opi_api.network.cloud.v1alpha1.Bgp\" \xda\x41\x04name\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/{name=bgps}/*\x12\xa2\x01\n\rCreateBGPPeer\x12\x34.opi_api.network.cloud.v1alpha1.CreateBGPPeerRequest\x1a\'.opi_api.network.cloud.v1alpha1.BGPPeer\"2\xda\x41\x12\x62gppeer,bgppeer_id\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/bgppeers:\x07\x62gppeer\x12\x83\x01\n\rDeleteBGPPeer\x12\x34.opi_api.network.cloud.v1alpha1.DeleteBGPPeerRequest\x1a\x16.google.protobuf.Empty\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17*\x15/v1/{name=bgppeers}/*\x12\xad\x01\n\rUpdateBGPPeer\x12\x34.opi_api.network.cloud.v1alpha1.UpdateBGPPeerRequest\x1a\'.opi_api.network.cloud.v1alpha1.BGPPeer\"=\xda\x41\x14\x62gppeer, update_mask\x82\xd3\xe4\x93\x02 2\x15/v1/{name=bgppeers}/*:\x07\x62gppeer\x12\x92\x01\n\x0cListBGPPeers\x12\x33.opi_api.network.cloud.v1alpha1.ListBGPPeersRequest\x1a\x34.opi_api.network.cloud.v1alpha1.ListBGPPeersResponse\"\x17\xda\x41\x00\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/bgppeers\x12\x8e\x01\n\nGetBGPPeer\x12\x31.opi_api.network.cloud.v1alpha1.GetBGPPeerRequest\x1a\'.opi_api.network.cloud.v1alpha1.BGPPeer\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/{name=bgppeers}/*\x12\xb0\x01\n\x0f\x43reateBGPPeerAf\x12\x36.opi_api.network.cloud.v1alpha1.CreateBGPPeerAfRequest\x1a).opi_api.network.cloud.v1alpha1.BGPPeerAf\":\xda\x41\x16\x62gppeeraf,bgppeeraf_id\x82\xd3\xe4\x93\x02\x1b\"\x0e/v1/bgppeerafs:\tbgppeeraf\x12\x89\x01\n\x0f\x44\x65leteBGPPeerAf\x12\x36.opi_api.network.cloud.v1alpha1.DeleteBGPPeerAfRequest\x1a\x16.google.protobuf.Empty\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19*\x17/v1/{name=bgppeerafs}/*\x12\xb9\x01\n\x0fUpdateBGPPeerAf\x12\x36.opi_api.network.cloud.v1alpha1.UpdateBGPPeerAfRequest\x1a).opi_api.network.cloud.v1alpha1.BGPPeerAf\"C\xda\x41\x16\x62gppeeraf, update_mask\x82\xd3\xe4\x93\x02$2\x17/v1/{name=bgppeerafs}/*:\tbgppeeraf\x12\x9a\x01\n\x0eListBGPPeerAfs\x12\x35.opi_api.network.cloud.v1alpha1.ListBGPPeerAfsRequest\x1a\x36.opi_api.network.cloud.v1alpha1.ListBGPPeerAfsResponse\"\x19\xda\x41\x00\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/bgppeerafs\x12\x96\x01\n\x0cGetBGPPeerAf\x12\x33.opi_api.network.cloud.v1alpha1.GetBGPPeerAfRequest\x1a).opi_api.network.cloud.v1alpha1.BGPPeerAf\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{name=bgppeerafs}/*\x12\xa2\x01\n\rCreateMapping\x12\x34.opi_api.network.cloud.v1alpha1.CreateMappingRequest\x1a\'.opi_api.network.cloud.v1alpha1.Mapping\"2\xda\x41\x12mapping,mapping_id\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/mappings:\x07mapping\x12\x83\x01\n\rDeleteMapping\x12\x34.opi_api.network.cloud.v1alpha1.DeleteMappingRequest\x1a\x16.google.protobuf.Empty\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17*\x15/v1/{name=mappings}/*\x12\xad\x01\n\rUpdateMapping\x12\x34.opi_api.network.cloud.v1alpha1.UpdateMappingRequest\x1a\'.opi_api.network.cloud.v1alpha1.Mapping\"=\xda\x41\x14mapping, update_mask\x82\xd3\xe4\x93\x02 2\x15/v1/{name=mappings}/*:\x07mapping\x12\x92\x01\n\x0cListMappings\x12\x33.opi_api.network.cloud.v1alpha1.ListMappingsRequest\x1a\x34.opi_api.network.cloud.v1alpha1.ListMappingsResponse\"\x17\xda\x41\x00\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/mappings\x12\x8e\x01\n\nGetMapping\x12\x31.opi_api.network.cloud.v1alpha1.GetMappingRequest\x1a\'.opi_api.network.cloud.v1alpha1.Mapping\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/{name=mappings}/*\x12\xa2\x01\n\rCreateNextHop\x12\x34.opi_api.network.cloud.v1alpha1.CreateNextHopRequest\x1a\'.opi_api.network.cloud.v1alpha1.NextHop\"2\xda\x41\x12nexthop,nexthop_id\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/nexthops:\x07nexthop\x12\x83\x01\n\rDeleteNextHop\x12\x34.opi_api.network.cloud.v1alpha1.DeleteNextHopRequest\x1a\x16.google.protobuf.Empty\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17*\x15/v1/{name=nexthops}/*\x12\xad\x01\n\rUpdateNextHop\x12\x34.opi_api.network.cloud.v1alpha1.UpdateNextHopRequest\x1a\'.opi_api.network.cloud.v1alpha1.NextHop\"=\xda\x41\x14nexthop, update_mask\x82\xd3\xe4\x93\x02 2\x15/v1/{name=nexthops}/*:\x07nexthop\x12\x90\x01\n\x0bListNextHop\x12\x32.opi_api.network.cloud.v1alpha1.ListNextHopRequest\x1a\x34.opi_api.network.cloud.v1alpha1.ListNextHopsResponse\"\x17\xda\x41\x00\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/nexthops\x12\x8e\x01\n\nGetNextHop\x12\x31.opi_api.network.cloud.v1alpha1.GetNextHopRequest\x1a\'.opi_api.network.cloud.v1alpha1.NextHop\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/{name=nexthops}/*\x12\xc5\x01\n\x12\x43reateNextHopGroup\x12\x39.opi_api.network.cloud.v1alpha1.CreateNextHopGroupRequest\x1a,.opi_api.network.cloud.v1alpha1.NextHopGroup\"F\xda\x41\x1cnexthopgroup,nexthopgroup_id\x82\xd3\xe4\x93\x02!\"\x11/v1/nexthopgroups:\x0cnexthopgroup\x12\x92\x01\n\x12\x44\x65leteNextHopGroup\x12\x39.opi_api.network.cloud.v1alpha1.DeleteNextHopGroupRequest\x1a\x16.google.protobuf.Empty\")\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/{name=nexthopgroups}/*\x12\xcb\x01\n\x12UpdateNextHopGroup\x12\x39.opi_api.network.cloud.v1alpha1.UpdateNextHopGroupRequest\x1a,.opi_api.network.cloud.v1alpha1.NextHopGroup\"L\xda\x41\x19nexthopgroup, update_mask\x82\xd3\xe4\x93\x02*2\x1a/v1/{name=nexthopgroups}/*:\x0cnexthopgroup\x12\xa6\x01\n\x11ListNextHopGroups\x12\x38.opi_api.network.cloud.v1alpha1.ListNextHopGroupsRequest\x1a\x39.opi_api.network.cloud.v1alpha1.ListNextHopGroupsResponse\"\x1c\xda\x41\x00\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/nexthopgroups\x12\xa2\x01\n\x0fGetNextHopGroup\x12\x36.opi_api.network.cloud.v1alpha1.GetNextHopGroupRequest\x1a,.opi_api.network.cloud.v1alpha1.NextHopGroup\")\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/{name=nexthopgroups}/*\x12\x9b\x01\n\x0c\x43reateSubnet\x12\x33.opi_api.network.cloud.v1alpha1.CreateSubnetRequest\x1a&.opi_api.network.cloud.v1alpha1.Subnet\".\xda\x41\x10subnet,subnet_id\x82\xd3\xe4\x93\x02\x15\"\x0b/v1/subnets:\x06subnet\x12\x80\x01\n\x0c\x44\x65leteSubnet\x12\x33.opi_api.network.cloud.v1alpha1.DeleteSubnetRequest\x1a\x16.google.protobuf.Empty\"#\xda\x41\x04name\x82\xd3\xe4\x93\x02\x16*\x14/v1/{name=subnets}/*\x12\xa7\x01\n\x0cUpdateSubnet\x12\x33.opi_api.network.cloud.v1alpha1.UpdateSubnetRequest\x1a&.opi_api.network.cloud.v1alpha1.Subnet\":\xda\x41\x13subnet, update_mask\x82\xd3\xe4\x93\x02\x1e\x32\x14/v1/{name=subnets}/*:\x06subnet\x12\x8e\x01\n\x0bListSubnets\x12\x32.opi_api.network.cloud.v1alpha1.ListSubnetsRequest\x1a\x33.opi_api.network.cloud.v1alpha1.ListSubnetsResponse\"\x16\xda\x41\x00\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/subnets\x12\x8a\x01\n\tGetSubnet\x12\x30.opi_api.network.cloud.v1alpha1.GetSubnetRequest\x1a&.opi_api.network.cloud.v1alpha1.Subnet\"#\xda\x41\x04name\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/{name=subnets}/*\x12\x9b\x01\n\x0c\x43reateTunnel\x12\x33.opi_api.network.cloud.v1alpha1.CreateTunnelRequest\x1a&.opi_api.network.cloud.v1alpha1.Tunnel\".\xda\x41\x10tunnel,tunnel_id\x82\xd3\xe4\x93\x02\x15\"\x0b/v1/tunnels:\x06tunnel\x12\x80\x01\n\x0c\x44\x65leteTunnel\x12\x33.opi_api.network.cloud.v1alpha1.DeleteTunnelRequest\x1a\x16.google.protobuf.Empty\"#\xda\x41\x04name\x82\xd3\xe4\x93\x02\x16*\x14/v1/{name=tunnels}/*\x12\xa7\x01\n\x0cUpdateTunnel\x12\x33.opi_api.network.cloud.v1alpha1.UpdateTunnelRequest\x1a&.opi_api.network.cloud.v1alpha1.Tunnel\":\xda\x41\x13tunnel, update_mask\x82\xd3\xe4\x93\x02\x1e\x32\x14/v1/{name=tunnels}/*:\x06tunnel\x12\x8e\x01\n\x0bListTunnels\x12\x32.opi_api.network.cloud.v1alpha1.ListTunnelsRequest\x1a\x33.opi_api.network.cloud.v1alpha1.ListTunnelsResponse\"\x16\xda\x41\x00\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/tunnels\x12\x8a\x01\n\tGetTunnel\x12\x30.opi_api.network.cloud.v1alpha1.GetTunnelRequest\x1a&.opi_api.network.cloud.v1alpha1.Tunnel\"#\xda\x41\x04name\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/{name=tunnels}/*\x12\x86\x01\n\tCreateVpc\x12\x30.opi_api.network.cloud.v1alpha1.CreateVpcRequest\x1a#.opi_api.network.cloud.v1alpha1.Vpc\"\"\xda\x41\nvpc,vpc_id\x82\xd3\xe4\x93\x02\x0f\"\x08/v1/vpcs:\x03vpc\x12w\n\tDeleteVpc\x12\x30.opi_api.network.cloud.v1alpha1.DeleteVpcRequest\x1a\x16.google.protobuf.Empty\" \xda\x41\x04name\x82\xd3\xe4\x93\x02\x13*\x11/v1/{name=vpcs}/*\x12\x95\x01\n\tUpdateVpc\x12\x30.opi_api.network.cloud.v1alpha1.UpdateVpcRequest\x1a#.opi_api.network.cloud.v1alpha1.Vpc\"1\xda\x41\x10vpc, update_mask\x82\xd3\xe4\x93\x02\x18\x32\x11/v1/{name=vpcs}/*:\x03vpc\x12\x82\x01\n\x08ListVpcs\x12/.opi_api.network.cloud.v1alpha1.ListVpcsRequest\x1a\x30.opi_api.network.cloud.v1alpha1.ListVpcsResponse\"\x13\xda\x41\x00\x82\xd3\xe4\x93\x02\n\x12\x08/v1/vpcs\x12~\n\x06GetVpc\x12-.opi_api.network.cloud.v1alpha1.GetVpcRequest\x1a#.opi_api.network.cloud.v1alpha1.Vpc\" \xda\x41\x04name\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/{name=vpcs}/*\x12\xa2\x01\n\rCreateVPCPeer\x12\x34.opi_api.network.cloud.v1alpha1.CreateVPCPeerRequest\x1a\'.opi_api.network.cloud.v1alpha1.VPCPeer\"2\xda\x41\x12vpcpeer,vpcpeer_id\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/vpcpeers:\x07vpcpeer\x12\x83\x01\n\rDeleteVPCPeer\x12\x34.opi_api.network.cloud.v1alpha1.DeleteVPCPeerRequest\x1a\x16.google.protobuf.Empty\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17*\x15/v1/{name=vpcpeers}/*\x12\xad\x01\n\rUpdateVPCPeer\x12\x34.opi_api.network.cloud.v1alpha1.UpdateVPCPeerRequest\x1a\'.opi_api.network.cloud.v1alpha1.VPCPeer\"=\xda\x41\x14vpcpeer, update_mask\x82\xd3\xe4\x93\x02 2\x15/v1/{name=vpcpeers}/*:\x07vpcpeer\x12\x92\x01\n\x0cListVPCPeers\x12\x33.opi_api.network.cloud.v1alpha1.ListVPCPeersRequest\x1a\x34.opi_api.network.cloud.v1alpha1.ListVPCPeersResponse\"\x17\xda\x41\x00\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/vpcpeers\x12\x8e\x01\n\nGetVPCPeer\x12\x31.opi_api.network.cloud.v1alpha1.GetVPCPeerRequest\x1a\'.opi_api.network.cloud.v1alpha1.VPCPeer\"$\xda\x41\x04name\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/{name=vpcpeers}/*\x12\xd3\x01\n\x14\x43reateSecurityPolicy\x12;.opi_api.network.cloud.v1alpha1.CreateSecurityPolicyRequest\x1a..opi_api.network.cloud.v1alpha1.SecurityPolicy\"N\xda\x41 securitypolicy,securitypolicy_id\x82\xd3\xe4\x93\x02%\"\x13/v1/securitypolicys:\x0esecuritypolicy\x12\x98\x01\n\x14\x44\x65leteSecurityPolicy\x12;.opi_api.network.cloud.v1alpha1.DeleteSecurityPolicyRequest\x1a\x16.google.protobuf.Empty\"+\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1e*\x1c/v1/{name=securitypolicys}/*\x12\xd7\x01\n\x14UpdateSecurityPolicy\x12;.opi_api.network.cloud.v1alpha1.UpdateSecurityPolicyRequest\x1a..opi_api.network.cloud.v1alpha1.SecurityPolicy\"R\xda\x41\x1bsecuritypolicy, update_mask\x82\xd3\xe4\x93\x02.2\x1c/v1/{name=securitypolicys}/*:\x0esecuritypolicy\x12\xae\x01\n\x13ListSecurityPolicys\x12:.opi_api.network.cloud.v1alpha1.ListSecurityPolicysRequest\x1a;.opi_api.network.cloud.v1alpha1.ListSecurityPolicysResponse\"\x1e\xda\x41\x00\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/securitypolicys\x12\xaa\x01\n\x11GetSecurityPolicy\x12\x38.opi_api.network.cloud.v1alpha1.GetSecurityPolicyRequest\x1a..opi_api.network.cloud.v1alpha1.SecurityPolicy\"+\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/{name=securitypolicys}/*\x12\xc5\x01\n\x12\x43reateSecurityRule\x12\x39.opi_api.network.cloud.v1alpha1.CreateSecurityRuleRequest\x1a,.opi_api.network.cloud.v1alpha1.SecurityRule\"F\xda\x41\x1csecurityrule,securityrule_id\x82\xd3\xe4\x93\x02!\"\x11/v1/securityrules:\x0csecurityrule\x12\x92\x01\n\x12\x44\x65leteSecurityRule\x12\x39.opi_api.network.cloud.v1alpha1.DeleteSecurityRuleRequest\x1a\x16.google.protobuf.Empty\")\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/{name=securityrules}/*\x12\xcb\x01\n\x12UpdateSecurityRule\x12\x39.opi_api.network.cloud.v1alpha1.UpdateSecurityRuleRequest\x1a,.opi_api.network.cloud.v1alpha1.SecurityRule\"L\xda\x41\x19securityrule, update_mask\x82\xd3\xe4\x93\x02*2\x1a/v1/{name=securityrules}/*:\x0csecurityrule\x12\xa6\x01\n\x11ListSecurityRules\x12\x38.opi_api.network.cloud.v1alpha1.ListSecurityRulesRequest\x1a\x39.opi_api.network.cloud.v1alpha1.ListSecurityRulesResponse\"\x1c\xda\x41\x00\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/securityrules\x12\xa2\x01\n\x0fGetSecurityRule\x12\x36.opi_api.network.cloud.v1alpha1.GetSecurityRuleRequest\x1a,.opi_api.network.cloud.v1alpha1.SecurityRule\")\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/{name=securityrules}/*\x12\xda\x01\n\x15\x43reateSecurityProfile\x12<.opi_api.network.cloud.v1alpha1.CreateSecurityProfileRequest\x1a/.opi_api.network.cloud.v1alpha1.SecurityProfile\"R\xda\x41\"securityprofile,securityprofile_id\x82\xd3\xe4\x93\x02\'\"\x14/v1/securityprofiles:\x0fsecurityprofile\x12\x9b\x01\n\x15\x44\x65leteSecurityProfile\x12<.opi_api.network.cloud.v1alpha1.DeleteSecurityProfileRequest\x1a\x16.google.protobuf.Empty\",\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1f*\x1d/v1/{name=securityprofiles}/*\x12\xdd\x01\n\x15UpdateSecurityProfile\x12<.opi_api.network.cloud.v1alpha1.UpdateSecurityProfileRequest\x1a/.opi_api.network.cloud.v1alpha1.SecurityProfile\"U\xda\x41\x1csecurityprofile, update_mask\x82\xd3\xe4\x93\x02\x30\x32\x1d/v1/{name=securityprofiles}/*:\x0fsecurityprofile\x12\xb2\x01\n\x14ListSecurityProfiles\x12;.opi_api.network.cloud.v1alpha1.ListSecurityProfilesRequest\x1a<.opi_api.network.cloud.v1alpha1.ListSecurityProfilesResponse\"\x1f\xda\x41\x00\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/securityprofiles\x12\xae\x01\n\x12GetSecurityProfile\x12\x39.opi_api.network.cloud.v1alpha1.GetSecurityProfileRequest\x1a/.opi_api.network.cloud.v1alpha1.SecurityProfile\",\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{name=securityprofiles}/*Bi\n\x1eopi_api.network.cloud.v1alpha1B\x08\x43loudRPCP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cloudrpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\010CloudRPCP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Device'
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['device']._options = None
  _globals['_CREATEDEVICEREQUEST'].fields_by_name['device']._serialized_options = b'\342A\001\002'
  _globals['_DELETEDEVICEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEDEVICEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Device'
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEDEVICEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Device'
  _globals['_LISTDEVICESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTDEVICESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Device'
  _globals['_GETDEVICEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETDEVICEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Device'
  _globals['_UPDATEPORTREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEPORTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1alpha1/Port'
  _globals['_LISTPORTSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTPORTSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1alpha1/Port'
  _globals['_GETPORTREQUEST'].fields_by_name['name']._options = None
  _globals['_GETPORTREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1alpha1/Port'
  _globals['_CREATEVNICREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEVNICREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1alpha1/Vnic'
  _globals['_CREATEVNICREQUEST'].fields_by_name['vnic']._options = None
  _globals['_CREATEVNICREQUEST'].fields_by_name['vnic']._serialized_options = b'\342A\001\002'
  _globals['_DELETEVNICREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVNICREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1alpha1/Vnic'
  _globals['_UPDATEVNICREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEVNICREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1alpha1/Vnic'
  _globals['_LISTVNICSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVNICSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1alpha1/Vnic'
  _globals['_GETVNICREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVNICREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1alpha1/Vnic'
  _globals['_CREATEINTERFACEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEINTERFACEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/Interface'
  _globals['_CREATEINTERFACEREQUEST'].fields_by_name['interface']._options = None
  _globals['_CREATEINTERFACEREQUEST'].fields_by_name['interface']._serialized_options = b'\342A\001\002'
  _globals['_DELETEINTERFACEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEINTERFACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/Interface'
  _globals['_UPDATEINTERFACEREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEINTERFACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/Interface'
  _globals['_LISTINTERFACESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTINTERFACESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/Interface'
  _globals['_GETINTERFACEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETINTERFACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/Interface'
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A%\n#opi_api.network.v1alpha1/RouteTable'
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['routetable']._options = None
  _globals['_CREATEROUTETABLEREQUEST'].fields_by_name['routetable']._serialized_options = b'\342A\001\002'
  _globals['_DELETEROUTETABLEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEROUTETABLEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.network.v1alpha1/RouteTable'
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEROUTETABLEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.network.v1alpha1/RouteTable'
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTROUTETABLESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A%\n#opi_api.network.v1alpha1/RouteTable'
  _globals['_GETROUTETABLEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETROUTETABLEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.network.v1alpha1/RouteTable'
  _globals['_CREATEROUTEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEROUTEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A \n\036opi_api.network.v1alpha1/Route'
  _globals['_CREATEROUTEREQUEST'].fields_by_name['route']._options = None
  _globals['_CREATEROUTEREQUEST'].fields_by_name['route']._serialized_options = b'\342A\001\002'
  _globals['_DELETEROUTEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEROUTEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036opi_api.network.v1alpha1/Route'
  _globals['_UPDATEROUTEREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEROUTEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036opi_api.network.v1alpha1/Route'
  _globals['_LISTROUTESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTROUTESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A \n\036opi_api.network.v1alpha1/Route'
  _globals['_GETROUTEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETROUTEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036opi_api.network.v1alpha1/Route'
  _globals['_CREATEUNDERLAYROUTEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEUNDERLAYROUTEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A(\n&opi_api.network.v1alpha1/UnderlayRoute'
  _globals['_CREATEUNDERLAYROUTEREQUEST'].fields_by_name['underlayroute']._options = None
  _globals['_CREATEUNDERLAYROUTEREQUEST'].fields_by_name['underlayroute']._serialized_options = b'\342A\001\002'
  _globals['_DELETEUNDERLAYROUTEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEUNDERLAYROUTEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A(\n&opi_api.network.v1alpha1/UnderlayRoute'
  _globals['_UPDATEUNDERLAYROUTEREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEUNDERLAYROUTEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A(\n&opi_api.network.v1alpha1/UnderlayRoute'
  _globals['_LISTUNDERLAYROUTESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTUNDERLAYROUTESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A(\n&opi_api.network.v1alpha1/UnderlayRoute'
  _globals['_GETUNDERLAYROUTEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETUNDERLAYROUTEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A(\n&opi_api.network.v1alpha1/UnderlayRoute'
  _globals['_CREATEBGPREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEBGPREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Bgp'
  _globals['_CREATEBGPREQUEST'].fields_by_name['bgp']._options = None
  _globals['_CREATEBGPREQUEST'].fields_by_name['bgp']._serialized_options = b'\342A\001\002'
  _globals['_DELETEBGPREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEBGPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Bgp'
  _globals['_UPDATEBGPREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEBGPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Bgp'
  _globals['_LISTBGPSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTBGPSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Bgp'
  _globals['_GETBGPREQUEST'].fields_by_name['name']._options = None
  _globals['_GETBGPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Bgp'
  _globals['_CREATEBGPPEERREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEBGPPEERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/BGPPeer'
  _globals['_CREATEBGPPEERREQUEST'].fields_by_name['bgppeer']._options = None
  _globals['_CREATEBGPPEERREQUEST'].fields_by_name['bgppeer']._serialized_options = b'\342A\001\002'
  _globals['_DELETEBGPPEERREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEBGPPEERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/BGPPeer'
  _globals['_UPDATEBGPPEERREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEBGPPEERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/BGPPeer'
  _globals['_LISTBGPPEERSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTBGPPEERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/BGPPeer'
  _globals['_GETBGPPEERREQUEST'].fields_by_name['name']._options = None
  _globals['_GETBGPPEERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/BGPPeer'
  _globals['_CREATEBGPPEERAFREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEBGPPEERAFREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/BGPPeerAf'
  _globals['_CREATEBGPPEERAFREQUEST'].fields_by_name['bgppeeraf']._options = None
  _globals['_CREATEBGPPEERAFREQUEST'].fields_by_name['bgppeeraf']._serialized_options = b'\342A\001\002'
  _globals['_DELETEBGPPEERAFREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEBGPPEERAFREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/BGPPeerAf'
  _globals['_UPDATEBGPPEERAFREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEBGPPEERAFREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/BGPPeerAf'
  _globals['_LISTBGPPEERAFSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTBGPPEERAFSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/BGPPeerAf'
  _globals['_GETBGPPEERAFREQUEST'].fields_by_name['name']._options = None
  _globals['_GETBGPPEERAFREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.network.v1alpha1/BGPPeerAf'
  _globals['_CREATEMAPPINGREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEMAPPINGREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/Mapping'
  _globals['_CREATEMAPPINGREQUEST'].fields_by_name['mapping']._options = None
  _globals['_CREATEMAPPINGREQUEST'].fields_by_name['mapping']._serialized_options = b'\342A\001\002'
  _globals['_DELETEMAPPINGREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEMAPPINGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/Mapping'
  _globals['_UPDATEMAPPINGREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEMAPPINGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/Mapping'
  _globals['_LISTMAPPINGSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTMAPPINGSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/Mapping'
  _globals['_GETMAPPINGREQUEST'].fields_by_name['name']._options = None
  _globals['_GETMAPPINGREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/Mapping'
  _globals['_CREATENEXTHOPREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATENEXTHOPREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/NextHop'
  _globals['_CREATENEXTHOPREQUEST'].fields_by_name['nexthop']._options = None
  _globals['_CREATENEXTHOPREQUEST'].fields_by_name['nexthop']._serialized_options = b'\342A\001\002'
  _globals['_DELETENEXTHOPREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENEXTHOPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/NextHop'
  _globals['_UPDATENEXTHOPREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATENEXTHOPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/NextHop'
  _globals['_LISTNEXTHOPREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNEXTHOPREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/NextHop'
  _globals['_GETNEXTHOPREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNEXTHOPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/NextHop'
  _globals['_CREATENEXTHOPGROUPREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATENEXTHOPGROUPREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/NextHopGroup'
  _globals['_CREATENEXTHOPGROUPREQUEST'].fields_by_name['nexthopgroup']._options = None
  _globals['_CREATENEXTHOPGROUPREQUEST'].fields_by_name['nexthopgroup']._serialized_options = b'\342A\001\002'
  _globals['_DELETENEXTHOPGROUPREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENEXTHOPGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/NextHopGroup'
  _globals['_UPDATENEXTHOPGROUPREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATENEXTHOPGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/NextHopGroup'
  _globals['_LISTNEXTHOPGROUPSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNEXTHOPGROUPSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/NextHopGroup'
  _globals['_GETNEXTHOPGROUPREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNEXTHOPGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/NextHopGroup'
  _globals['_CREATESUBNETREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATESUBNETREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Subnet'
  _globals['_CREATESUBNETREQUEST'].fields_by_name['subnet']._options = None
  _globals['_CREATESUBNETREQUEST'].fields_by_name['subnet']._serialized_options = b'\342A\001\002'
  _globals['_DELETESUBNETREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETESUBNETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Subnet'
  _globals['_UPDATESUBNETREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATESUBNETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Subnet'
  _globals['_LISTSUBNETSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTSUBNETSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Subnet'
  _globals['_GETSUBNETREQUEST'].fields_by_name['name']._options = None
  _globals['_GETSUBNETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Subnet'
  _globals['_CREATETUNNELREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATETUNNELREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Tunnel'
  _globals['_CREATETUNNELREQUEST'].fields_by_name['tunnel']._options = None
  _globals['_CREATETUNNELREQUEST'].fields_by_name['tunnel']._serialized_options = b'\342A\001\002'
  _globals['_DELETETUNNELREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETETUNNELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Tunnel'
  _globals['_UPDATETUNNELREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATETUNNELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Tunnel'
  _globals['_LISTTUNNELSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTTUNNELSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Tunnel'
  _globals['_GETTUNNELREQUEST'].fields_by_name['name']._options = None
  _globals['_GETTUNNELREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.network.v1alpha1/Tunnel'
  _globals['_CREATEVPCREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEVPCREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Vpc'
  _globals['_CREATEVPCREQUEST'].fields_by_name['vpc']._options = None
  _globals['_CREATEVPCREQUEST'].fields_by_name['vpc']._serialized_options = b'\342A\001\002'
  _globals['_DELETEVPCREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVPCREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Vpc'
  _globals['_UPDATEVPCREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEVPCREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Vpc'
  _globals['_LISTVPCSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVPCSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Vpc'
  _globals['_GETVPCREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVPCREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.network.v1alpha1/Vpc'
  _globals['_CREATEVPCPEERREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATEVPCPEERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/VPCPeer'
  _globals['_CREATEVPCPEERREQUEST'].fields_by_name['vpcpeer']._options = None
  _globals['_CREATEVPCPEERREQUEST'].fields_by_name['vpcpeer']._serialized_options = b'\342A\001\002'
  _globals['_DELETEVPCPEERREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVPCPEERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/VPCPeer'
  _globals['_UPDATEVPCPEERREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATEVPCPEERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/VPCPeer'
  _globals['_LISTVPCPEERSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVPCPEERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/VPCPeer'
  _globals['_GETVPCPEERREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVPCPEERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.network.v1alpha1/VPCPeer'
  _globals['_CREATESECURITYPOLICYREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATESECURITYPOLICYREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.network.v1alpha1/SecurityPolicy'
  _globals['_CREATESECURITYPOLICYREQUEST'].fields_by_name['securitypolicy']._options = None
  _globals['_CREATESECURITYPOLICYREQUEST'].fields_by_name['securitypolicy']._serialized_options = b'\342A\001\002'
  _globals['_DELETESECURITYPOLICYREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETESECURITYPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.network.v1alpha1/SecurityPolicy'
  _globals['_UPDATESECURITYPOLICYREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATESECURITYPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.network.v1alpha1/SecurityPolicy'
  _globals['_LISTSECURITYPOLICYSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTSECURITYPOLICYSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.network.v1alpha1/SecurityPolicy'
  _globals['_GETSECURITYPOLICYREQUEST'].fields_by_name['name']._options = None
  _globals['_GETSECURITYPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.network.v1alpha1/SecurityPolicy'
  _globals['_CREATESECURITYRULEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATESECURITYRULEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/SecurityRule'
  _globals['_CREATESECURITYRULEREQUEST'].fields_by_name['securityrule']._options = None
  _globals['_CREATESECURITYRULEREQUEST'].fields_by_name['securityrule']._serialized_options = b'\342A\001\002'
  _globals['_DELETESECURITYRULEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETESECURITYRULEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/SecurityRule'
  _globals['_UPDATESECURITYRULEREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATESECURITYRULEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/SecurityRule'
  _globals['_LISTSECURITYRULESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTSECURITYRULESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/SecurityRule'
  _globals['_GETSECURITYRULEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETSECURITYRULEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\'\n%opi_api.network.v1alpha1/SecurityRule'
  _globals['_CREATESECURITYPROFILEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATESECURITYPROFILEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A*\n(opi_api.network.v1alpha1/SecurityProfile'
  _globals['_CREATESECURITYPROFILEREQUEST'].fields_by_name['securityprofile']._options = None
  _globals['_CREATESECURITYPROFILEREQUEST'].fields_by_name['securityprofile']._serialized_options = b'\342A\001\002'
  _globals['_DELETESECURITYPROFILEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETESECURITYPROFILEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A*\n(opi_api.network.v1alpha1/SecurityProfile'
  _globals['_UPDATESECURITYPROFILEREQUEST'].fields_by_name['name']._options = None
  _globals['_UPDATESECURITYPROFILEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A*\n(opi_api.network.v1alpha1/SecurityProfile'
  _globals['_LISTSECURITYPROFILESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTSECURITYPROFILESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A*\n(opi_api.network.v1alpha1/SecurityProfile'
  _globals['_GETSECURITYPROFILEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETSECURITYPROFILEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A*\n(opi_api.network.v1alpha1/SecurityProfile'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetDeviceCapabilities']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetDeviceCapabilities']._serialized_options = b'\332A\000\202\323\344\223\002\031\022\027/v1/devicecapabilitiess'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateDevice']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateDevice']._serialized_options = b'\332A\020device,device_id\202\323\344\223\002\025\"\013/v1/devices:\006device'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteDevice']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteDevice']._serialized_options = b'\332A\004name\202\323\344\223\002\026*\024/v1/{name=devices}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateDevice']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateDevice']._serialized_options = b'\332A\023device, update_mask\202\323\344\223\002\0362\024/v1/{name=devices}/*:\006device'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListDevices']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListDevices']._serialized_options = b'\332A\000\202\323\344\223\002\r\022\013/v1/devices'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetDevice']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetDevice']._serialized_options = b'\332A\004name\202\323\344\223\002\026\022\024/v1/{name=devices}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdatePort']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdatePort']._serialized_options = b'\332A\021port, update_mask\202\323\344\223\002\0322\022/v1/{name=ports}/*:\004port'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListPorts']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListPorts']._serialized_options = b'\332A\000\202\323\344\223\002\013\022\t/v1/ports'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetPort']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetPort']._serialized_options = b'\332A\004name\202\323\344\223\002\024\022\022/v1/{name=ports}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateVnic']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateVnic']._serialized_options = b'\332A\014vnic,vnic_id\202\323\344\223\002\021\"\t/v1/vnics:\004vnic'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteVnic']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteVnic']._serialized_options = b'\332A\004name\202\323\344\223\002\024*\022/v1/{name=vnics}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateVnic']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateVnic']._serialized_options = b'\332A\021vnic, update_mask\202\323\344\223\002\0322\022/v1/{name=vnics}/*:\004vnic'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListVnics']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListVnics']._serialized_options = b'\332A\000\202\323\344\223\002\013\022\t/v1/vnics'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetVnic']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetVnic']._serialized_options = b'\332A\004name\202\323\344\223\002\024\022\022/v1/{name=vnics}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateInterface']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateInterface']._serialized_options = b'\332A\026interface,interface_id\202\323\344\223\002\033\"\016/v1/interfaces:\tinterface'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteInterface']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteInterface']._serialized_options = b'\332A\004name\202\323\344\223\002\031*\027/v1/{name=interfaces}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateInterface']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateInterface']._serialized_options = b'\332A\026interface, update_mask\202\323\344\223\002$2\027/v1/{name=interfaces}/*:\tinterface'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListInterfaces']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListInterfaces']._serialized_options = b'\332A\000\202\323\344\223\002\020\022\016/v1/interfaces'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetInterface']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetInterface']._serialized_options = b'\332A\004name\202\323\344\223\002\031\022\027/v1/{name=interfaces}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateRouteTable']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateRouteTable']._serialized_options = b'\332A\030routetable,routetable_id\202\323\344\223\002\035\"\017/v1/routetables:\nroutetable'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteRouteTable']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteRouteTable']._serialized_options = b'\332A\004name\202\323\344\223\002\032*\030/v1/{name=routetables}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateRouteTable']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateRouteTable']._serialized_options = b'\332A\027routetable, update_mask\202\323\344\223\002&2\030/v1/{name=routetables}/*:\nroutetable'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListRouteTables']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListRouteTables']._serialized_options = b'\332A\000\202\323\344\223\002\021\022\017/v1/routetables'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetRouteTable']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetRouteTable']._serialized_options = b'\332A\004name\202\323\344\223\002\032\022\030/v1/{name=routetables}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateRoute']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateRoute']._serialized_options = b'\332A\016route,route_id\202\323\344\223\002\023\"\n/v1/routes:\005route'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteRoute']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteRoute']._serialized_options = b'\332A\004name\202\323\344\223\002\025*\023/v1/{name=routes}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateRoute']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateRoute']._serialized_options = b'\332A\022route, update_mask\202\323\344\223\002\0342\023/v1/{name=routes}/*:\005route'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListRoutes']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListRoutes']._serialized_options = b'\332A\000\202\323\344\223\002\014\022\n/v1/routes'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetRoute']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetRoute']._serialized_options = b'\332A\004name\202\323\344\223\002\025\022\023/v1/{name=routes}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateUnderlayRoute']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateUnderlayRoute']._serialized_options = b'\332A\036underlayroute,underlayroute_id\202\323\344\223\002#\"\022/v1/underlayroutes:\runderlayroute'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteUnderlayRoute']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteUnderlayRoute']._serialized_options = b'\332A\004name\202\323\344\223\002\035*\033/v1/{name=underlayroutes}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateUnderlayRoute']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateUnderlayRoute']._serialized_options = b'\332A\032underlayroute, update_mask\202\323\344\223\002,2\033/v1/{name=underlayroutes}/*:\runderlayroute'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListUnderlayRoutes']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListUnderlayRoutes']._serialized_options = b'\332A\000\202\323\344\223\002\024\022\022/v1/underlayroutes'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetUnderlayRoute']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetUnderlayRoute']._serialized_options = b'\332A\004name\202\323\344\223\002\035\022\033/v1/{name=underlayroutes}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateBgp']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateBgp']._serialized_options = b'\332A\nbgp,bgp_id\202\323\344\223\002\017\"\010/v1/bgps:\003bgp'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteBgp']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteBgp']._serialized_options = b'\332A\004name\202\323\344\223\002\023*\021/v1/{name=bgps}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateBgp']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateBgp']._serialized_options = b'\332A\020bgp, update_mask\202\323\344\223\002\0302\021/v1/{name=bgps}/*:\003bgp'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListBgps']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListBgps']._serialized_options = b'\332A\000\202\323\344\223\002\n\022\010/v1/bgps'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetBgp']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetBgp']._serialized_options = b'\332A\004name\202\323\344\223\002\023\022\021/v1/{name=bgps}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateBGPPeer']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateBGPPeer']._serialized_options = b'\332A\022bgppeer,bgppeer_id\202\323\344\223\002\027\"\014/v1/bgppeers:\007bgppeer'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteBGPPeer']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteBGPPeer']._serialized_options = b'\332A\004name\202\323\344\223\002\027*\025/v1/{name=bgppeers}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateBGPPeer']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateBGPPeer']._serialized_options = b'\332A\024bgppeer, update_mask\202\323\344\223\002 2\025/v1/{name=bgppeers}/*:\007bgppeer'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListBGPPeers']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListBGPPeers']._serialized_options = b'\332A\000\202\323\344\223\002\016\022\014/v1/bgppeers'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetBGPPeer']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetBGPPeer']._serialized_options = b'\332A\004name\202\323\344\223\002\027\022\025/v1/{name=bgppeers}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateBGPPeerAf']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateBGPPeerAf']._serialized_options = b'\332A\026bgppeeraf,bgppeeraf_id\202\323\344\223\002\033\"\016/v1/bgppeerafs:\tbgppeeraf'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteBGPPeerAf']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteBGPPeerAf']._serialized_options = b'\332A\004name\202\323\344\223\002\031*\027/v1/{name=bgppeerafs}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateBGPPeerAf']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateBGPPeerAf']._serialized_options = b'\332A\026bgppeeraf, update_mask\202\323\344\223\002$2\027/v1/{name=bgppeerafs}/*:\tbgppeeraf'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListBGPPeerAfs']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListBGPPeerAfs']._serialized_options = b'\332A\000\202\323\344\223\002\020\022\016/v1/bgppeerafs'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetBGPPeerAf']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetBGPPeerAf']._serialized_options = b'\332A\004name\202\323\344\223\002\031\022\027/v1/{name=bgppeerafs}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateMapping']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateMapping']._serialized_options = b'\332A\022mapping,mapping_id\202\323\344\223\002\027\"\014/v1/mappings:\007mapping'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteMapping']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteMapping']._serialized_options = b'\332A\004name\202\323\344\223\002\027*\025/v1/{name=mappings}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateMapping']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateMapping']._serialized_options = b'\332A\024mapping, update_mask\202\323\344\223\002 2\025/v1/{name=mappings}/*:\007mapping'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListMappings']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListMappings']._serialized_options = b'\332A\000\202\323\344\223\002\016\022\014/v1/mappings'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetMapping']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetMapping']._serialized_options = b'\332A\004name\202\323\344\223\002\027\022\025/v1/{name=mappings}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateNextHop']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateNextHop']._serialized_options = b'\332A\022nexthop,nexthop_id\202\323\344\223\002\027\"\014/v1/nexthops:\007nexthop'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteNextHop']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteNextHop']._serialized_options = b'\332A\004name\202\323\344\223\002\027*\025/v1/{name=nexthops}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateNextHop']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateNextHop']._serialized_options = b'\332A\024nexthop, update_mask\202\323\344\223\002 2\025/v1/{name=nexthops}/*:\007nexthop'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListNextHop']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListNextHop']._serialized_options = b'\332A\000\202\323\344\223\002\016\022\014/v1/nexthops'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetNextHop']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetNextHop']._serialized_options = b'\332A\004name\202\323\344\223\002\027\022\025/v1/{name=nexthops}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateNextHopGroup']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateNextHopGroup']._serialized_options = b'\332A\034nexthopgroup,nexthopgroup_id\202\323\344\223\002!\"\021/v1/nexthopgroups:\014nexthopgroup'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteNextHopGroup']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteNextHopGroup']._serialized_options = b'\332A\004name\202\323\344\223\002\034*\032/v1/{name=nexthopgroups}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateNextHopGroup']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateNextHopGroup']._serialized_options = b'\332A\031nexthopgroup, update_mask\202\323\344\223\002*2\032/v1/{name=nexthopgroups}/*:\014nexthopgroup'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListNextHopGroups']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListNextHopGroups']._serialized_options = b'\332A\000\202\323\344\223\002\023\022\021/v1/nexthopgroups'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetNextHopGroup']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetNextHopGroup']._serialized_options = b'\332A\004name\202\323\344\223\002\034\022\032/v1/{name=nexthopgroups}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateSubnet']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateSubnet']._serialized_options = b'\332A\020subnet,subnet_id\202\323\344\223\002\025\"\013/v1/subnets:\006subnet'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteSubnet']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteSubnet']._serialized_options = b'\332A\004name\202\323\344\223\002\026*\024/v1/{name=subnets}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateSubnet']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateSubnet']._serialized_options = b'\332A\023subnet, update_mask\202\323\344\223\002\0362\024/v1/{name=subnets}/*:\006subnet'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListSubnets']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListSubnets']._serialized_options = b'\332A\000\202\323\344\223\002\r\022\013/v1/subnets'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetSubnet']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetSubnet']._serialized_options = b'\332A\004name\202\323\344\223\002\026\022\024/v1/{name=subnets}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateTunnel']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateTunnel']._serialized_options = b'\332A\020tunnel,tunnel_id\202\323\344\223\002\025\"\013/v1/tunnels:\006tunnel'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteTunnel']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteTunnel']._serialized_options = b'\332A\004name\202\323\344\223\002\026*\024/v1/{name=tunnels}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateTunnel']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateTunnel']._serialized_options = b'\332A\023tunnel, update_mask\202\323\344\223\002\0362\024/v1/{name=tunnels}/*:\006tunnel'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListTunnels']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListTunnels']._serialized_options = b'\332A\000\202\323\344\223\002\r\022\013/v1/tunnels'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetTunnel']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetTunnel']._serialized_options = b'\332A\004name\202\323\344\223\002\026\022\024/v1/{name=tunnels}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateVpc']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateVpc']._serialized_options = b'\332A\nvpc,vpc_id\202\323\344\223\002\017\"\010/v1/vpcs:\003vpc'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteVpc']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteVpc']._serialized_options = b'\332A\004name\202\323\344\223\002\023*\021/v1/{name=vpcs}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateVpc']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateVpc']._serialized_options = b'\332A\020vpc, update_mask\202\323\344\223\002\0302\021/v1/{name=vpcs}/*:\003vpc'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListVpcs']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListVpcs']._serialized_options = b'\332A\000\202\323\344\223\002\n\022\010/v1/vpcs'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetVpc']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetVpc']._serialized_options = b'\332A\004name\202\323\344\223\002\023\022\021/v1/{name=vpcs}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateVPCPeer']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateVPCPeer']._serialized_options = b'\332A\022vpcpeer,vpcpeer_id\202\323\344\223\002\027\"\014/v1/vpcpeers:\007vpcpeer'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteVPCPeer']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteVPCPeer']._serialized_options = b'\332A\004name\202\323\344\223\002\027*\025/v1/{name=vpcpeers}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateVPCPeer']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateVPCPeer']._serialized_options = b'\332A\024vpcpeer, update_mask\202\323\344\223\002 2\025/v1/{name=vpcpeers}/*:\007vpcpeer'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListVPCPeers']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListVPCPeers']._serialized_options = b'\332A\000\202\323\344\223\002\016\022\014/v1/vpcpeers'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetVPCPeer']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetVPCPeer']._serialized_options = b'\332A\004name\202\323\344\223\002\027\022\025/v1/{name=vpcpeers}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateSecurityPolicy']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateSecurityPolicy']._serialized_options = b'\332A securitypolicy,securitypolicy_id\202\323\344\223\002%\"\023/v1/securitypolicys:\016securitypolicy'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteSecurityPolicy']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteSecurityPolicy']._serialized_options = b'\332A\004name\202\323\344\223\002\036*\034/v1/{name=securitypolicys}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateSecurityPolicy']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateSecurityPolicy']._serialized_options = b'\332A\033securitypolicy, update_mask\202\323\344\223\002.2\034/v1/{name=securitypolicys}/*:\016securitypolicy'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListSecurityPolicys']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListSecurityPolicys']._serialized_options = b'\332A\000\202\323\344\223\002\025\022\023/v1/securitypolicys'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetSecurityPolicy']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetSecurityPolicy']._serialized_options = b'\332A\004name\202\323\344\223\002\036\022\034/v1/{name=securitypolicys}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateSecurityRule']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateSecurityRule']._serialized_options = b'\332A\034securityrule,securityrule_id\202\323\344\223\002!\"\021/v1/securityrules:\014securityrule'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteSecurityRule']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteSecurityRule']._serialized_options = b'\332A\004name\202\323\344\223\002\034*\032/v1/{name=securityrules}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateSecurityRule']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateSecurityRule']._serialized_options = b'\332A\031securityrule, update_mask\202\323\344\223\002*2\032/v1/{name=securityrules}/*:\014securityrule'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListSecurityRules']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListSecurityRules']._serialized_options = b'\332A\000\202\323\344\223\002\023\022\021/v1/securityrules'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetSecurityRule']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetSecurityRule']._serialized_options = b'\332A\004name\202\323\344\223\002\034\022\032/v1/{name=securityrules}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateSecurityProfile']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['CreateSecurityProfile']._serialized_options = b'\332A\"securityprofile,securityprofile_id\202\323\344\223\002\'\"\024/v1/securityprofiles:\017securityprofile'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteSecurityProfile']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['DeleteSecurityProfile']._serialized_options = b'\332A\004name\202\323\344\223\002\037*\035/v1/{name=securityprofiles}/*'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateSecurityProfile']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['UpdateSecurityProfile']._serialized_options = b'\332A\034securityprofile, update_mask\202\323\344\223\00202\035/v1/{name=securityprofiles}/*:\017securityprofile'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListSecurityProfiles']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['ListSecurityProfiles']._serialized_options = b'\332A\000\202\323\344\223\002\026\022\024/v1/securityprofiles'
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetSecurityProfile']._options = None
  _globals['_CLOUDINFRASERVICE'].methods_by_name['GetSecurityProfile']._serialized_options = b'\332A\004name\202\323\344\223\002\037\022\035/v1/{name=securityprofiles}/*'
  _globals['_GETDEVICECAPABILITIESREQUEST']._serialized_start=418
  _globals['_GETDEVICECAPABILITIESREQUEST']._serialized_end=448
  _globals['_CREATEDEVICEREQUEST']._serialized_start=451
  _globals['_CREATEDEVICEREQUEST']._serialized_end=637
  _globals['_DELETEDEVICEREQUEST']._serialized_start=639
  _globals['_DELETEDEVICEREQUEST']._serialized_end=759
  _globals['_UPDATEDEVICEREQUEST']._serialized_start=762
  _globals['_UPDATEDEVICEREQUEST']._serialized_end=970
  _globals['_LISTDEVICESREQUEST']._serialized_start=973
  _globals['_LISTDEVICESREQUEST']._serialized_end=1119
  _globals['_LISTDEVICESRESPONSE']._serialized_start=1121
  _globals['_LISTDEVICESRESPONSE']._serialized_end=1246
  _globals['_GETDEVICEREQUEST']._serialized_start=1248
  _globals['_GETDEVICEREQUEST']._serialized_end=1328
  _globals['_UPDATEPORTREQUEST']._serialized_start=1331
  _globals['_UPDATEPORTREQUEST']._serialized_end=1529
  _globals['_LISTPORTSREQUEST']._serialized_start=1532
  _globals['_LISTPORTSREQUEST']._serialized_end=1674
  _globals['_LISTPORTSRESPONSE']._serialized_start=1676
  _globals['_LISTPORTSRESPONSE']._serialized_end=1793
  _globals['_GETPORTREQUEST']._serialized_start=1795
  _globals['_GETPORTREQUEST']._serialized_end=1871
  _globals['_CREATEVNICREQUEST']._serialized_start=1874
  _globals['_CREATEVNICREQUEST']._serialized_end=2046
  _globals['_DELETEVNICREQUEST']._serialized_start=2048
  _globals['_DELETEVNICREQUEST']._serialized_end=2164
  _globals['_UPDATEVNICREQUEST']._serialized_start=2167
  _globals['_UPDATEVNICREQUEST']._serialized_end=2365
  _globals['_LISTVNICSREQUEST']._serialized_start=2368
  _globals['_LISTVNICSREQUEST']._serialized_end=2510
  _globals['_LISTVNICSRESPONSE']._serialized_start=2512
  _globals['_LISTVNICSRESPONSE']._serialized_end=2629
  _globals['_GETVNICREQUEST']._serialized_start=2631
  _globals['_GETVNICREQUEST']._serialized_end=2707
  _globals['_CREATEINTERFACEREQUEST']._serialized_start=2710
  _globals['_CREATEINTERFACEREQUEST']._serialized_end=2917
  _globals['_DELETEINTERFACEREQUEST']._serialized_start=2919
  _globals['_DELETEINTERFACEREQUEST']._serialized_end=3045
  _globals['_UPDATEINTERFACEREQUEST']._serialized_start=3048
  _globals['_UPDATEINTERFACEREQUEST']._serialized_end=3271
  _globals['_LISTINTERFACESREQUEST']._serialized_start=3274
  _globals['_LISTINTERFACESREQUEST']._serialized_end=3426
  _globals['_LISTINTERFACESRESPONSE']._serialized_start=3429
  _globals['_LISTINTERFACESRESPONSE']._serialized_end=3566
  _globals['_GETINTERFACEREQUEST']._serialized_start=3568
  _globals['_GETINTERFACEREQUEST']._serialized_end=3654
  _globals['_CREATEROUTETABLEREQUEST']._serialized_start=3657
  _globals['_CREATEROUTETABLEREQUEST']._serialized_end=3871
  _globals['_DELETEROUTETABLEREQUEST']._serialized_start=3874
  _globals['_DELETEROUTETABLEREQUEST']._serialized_end=4002
  _globals['_UPDATEROUTETABLEREQUEST']._serialized_start=4005
  _globals['_UPDATEROUTETABLEREQUEST']._serialized_end=4233
  _globals['_LISTROUTETABLESREQUEST']._serialized_start=4236
  _globals['_LISTROUTETABLESREQUEST']._serialized_end=4390
  _globals['_LISTROUTETABLESRESPONSE']._serialized_start=4393
  _globals['_LISTROUTETABLESRESPONSE']._serialized_end=4534
  _globals['_GETROUTETABLEREQUEST']._serialized_start=4536
  _globals['_GETROUTETABLEREQUEST']._serialized_end=4624
  _globals['_CREATEROUTEREQUEST']._serialized_start=4627
  _globals['_CREATEROUTEREQUEST']._serialized_end=4806
  _globals['_DELETEROUTEREQUEST']._serialized_start=4808
  _globals['_DELETEROUTEREQUEST']._serialized_end=4926
  _globals['_UPDATEROUTEREQUEST']._serialized_start=4929
  _globals['_UPDATEROUTEREQUEST']._serialized_end=5132
  _globals['_LISTROUTESREQUEST']._serialized_start=5135
  _globals['_LISTROUTESREQUEST']._serialized_end=5279
  _globals['_LISTROUTESRESPONSE']._serialized_start=5281
  _globals['_LISTROUTESRESPONSE']._serialized_end=5402
  _globals['_GETROUTEREQUEST']._serialized_start=5404
  _globals['_GETROUTEREQUEST']._serialized_end=5482
  _globals['_CREATEUNDERLAYROUTEREQUEST']._serialized_start=5485
  _globals['_CREATEUNDERLAYROUTEREQUEST']._serialized_end=5720
  _globals['_DELETEUNDERLAYROUTEREQUEST']._serialized_start=5723
  _globals['_DELETEUNDERLAYROUTEREQUEST']._serialized_end=5857
  _globals['_UPDATEUNDERLAYROUTEREQUEST']._serialized_start=5860
  _globals['_UPDATEUNDERLAYROUTEREQUEST']._serialized_end=6103
  _globals['_LISTUNDERLAYROUTESREQUEST']._serialized_start=6106
  _globals['_LISTUNDERLAYROUTESREQUEST']._serialized_end=6266
  _globals['_LISTUNDERLAYROUTESRESPONSE']._serialized_start=6269
  _globals['_LISTUNDERLAYROUTESRESPONSE']._serialized_end=6422
  _globals['_GETUNDERLAYROUTEREQUEST']._serialized_start=6424
  _globals['_GETUNDERLAYROUTEREQUEST']._serialized_end=6518
  _globals['_CREATEBGPREQUEST']._serialized_start=6521
  _globals['_CREATEBGPREQUEST']._serialized_end=6686
  _globals['_DELETEBGPREQUEST']._serialized_start=6688
  _globals['_DELETEBGPREQUEST']._serialized_end=6802
  _globals['_UPDATEBGPREQUEST']._serialized_start=6805
  _globals['_UPDATEBGPREQUEST']._serialized_end=6998
  _globals['_LISTBGPSREQUEST']._serialized_start=7001
  _globals['_LISTBGPSREQUEST']._serialized_end=7141
  _globals['_LISTBGPSRESPONSE']._serialized_start=7143
  _globals['_LISTBGPSRESPONSE']._serialized_end=7256
  _globals['_GETBGPREQUEST']._serialized_start=7258
  _globals['_GETBGPREQUEST']._serialized_end=7332
  _globals['_CREATEBGPPEERREQUEST']._serialized_start=7335
  _globals['_CREATEBGPPEERREQUEST']._serialized_end=7528
  _globals['_DELETEBGPPEERREQUEST']._serialized_start=7530
  _globals['_DELETEBGPPEERREQUEST']._serialized_end=7652
  _globals['_UPDATEBGPPEERREQUEST']._serialized_start=7655
  _globals['_UPDATEBGPPEERREQUEST']._serialized_end=7868
  _globals['_LISTBGPPEERSREQUEST']._serialized_start=7871
  _globals['_LISTBGPPEERSREQUEST']._serialized_end=8019
  _globals['_LISTBGPPEERSRESPONSE']._serialized_start=8022
  _globals['_LISTBGPPEERSRESPONSE']._serialized_end=8151
  _globals['_GETBGPPEERREQUEST']._serialized_start=8153
  _globals['_GETBGPPEERREQUEST']._serialized_end=8235
  _globals['_CREATEBGPPEERAFREQUEST']._serialized_start=8238
  _globals['_CREATEBGPPEERAFREQUEST']._serialized_end=8445
  _globals['_DELETEBGPPEERAFREQUEST']._serialized_start=8447
  _globals['_DELETEBGPPEERAFREQUEST']._serialized_end=8573
  _globals['_UPDATEBGPPEERAFREQUEST']._serialized_start=8576
  _globals['_UPDATEBGPPEERAFREQUEST']._serialized_end=8799
  _globals['_LISTBGPPEERAFSREQUEST']._serialized_start=8802
  _globals['_LISTBGPPEERAFSREQUEST']._serialized_end=8954
  _globals['_LISTBGPPEERAFSRESPONSE']._serialized_start=8957
  _globals['_LISTBGPPEERAFSRESPONSE']._serialized_end=9094
  _globals['_GETBGPPEERAFREQUEST']._serialized_start=9096
  _globals['_GETBGPPEERAFREQUEST']._serialized_end=9182
  _globals['_CREATEMAPPINGREQUEST']._serialized_start=9185
  _globals['_CREATEMAPPINGREQUEST']._serialized_end=9378
  _globals['_DELETEMAPPINGREQUEST']._serialized_start=9380
  _globals['_DELETEMAPPINGREQUEST']._serialized_end=9502
  _globals['_UPDATEMAPPINGREQUEST']._serialized_start=9505
  _globals['_UPDATEMAPPINGREQUEST']._serialized_end=9718
  _globals['_LISTMAPPINGSREQUEST']._serialized_start=9721
  _globals['_LISTMAPPINGSREQUEST']._serialized_end=9869
  _globals['_LISTMAPPINGSRESPONSE']._serialized_start=9872
  _globals['_LISTMAPPINGSRESPONSE']._serialized_end=10001
  _globals['_GETMAPPINGREQUEST']._serialized_start=10003
  _globals['_GETMAPPINGREQUEST']._serialized_end=10085
  _globals['_CREATENEXTHOPREQUEST']._serialized_start=10088
  _globals['_CREATENEXTHOPREQUEST']._serialized_end=10281
  _globals['_DELETENEXTHOPREQUEST']._serialized_start=10283
  _globals['_DELETENEXTHOPREQUEST']._serialized_end=10405
  _globals['_UPDATENEXTHOPREQUEST']._serialized_start=10408
  _globals['_UPDATENEXTHOPREQUEST']._serialized_end=10621
  _globals['_LISTNEXTHOPREQUEST']._serialized_start=10624
  _globals['_LISTNEXTHOPREQUEST']._serialized_end=10771
  _globals['_LISTNEXTHOPSRESPONSE']._serialized_start=10774
  _globals['_LISTNEXTHOPSRESPONSE']._serialized_end=10903
  _globals['_GETNEXTHOPREQUEST']._serialized_start=10905
  _globals['_GETNEXTHOPREQUEST']._serialized_end=10987
  _globals['_CREATENEXTHOPGROUPREQUEST']._serialized_start=10990
  _globals['_CREATENEXTHOPGROUPREQUEST']._serialized_end=11218
  _globals['_DELETENEXTHOPGROUPREQUEST']._serialized_start=11221
  _globals['_DELETENEXTHOPGROUPREQUEST']._serialized_end=11353
  _globals['_UPDATENEXTHOPGROUPREQUEST']._serialized_start=11356
  _globals['_UPDATENEXTHOPGROUPREQUEST']._serialized_end=11594
  _globals['_LISTNEXTHOPGROUPSREQUEST']._serialized_start=11597
  _globals['_LISTNEXTHOPGROUPSREQUEST']._serialized_end=11755
  _globals['_LISTNEXTHOPGROUPSRESPONSE']._serialized_start=11758
  _globals['_LISTNEXTHOPGROUPSRESPONSE']._serialized_end=11907
  _globals['_GETNEXTHOPGROUPREQUEST']._serialized_start=11909
  _globals['_GETNEXTHOPGROUPREQUEST']._serialized_end=12001
  _globals['_CREATESUBNETREQUEST']._serialized_start=12004
  _globals['_CREATESUBNETREQUEST']._serialized_end=12190
  _globals['_DELETESUBNETREQUEST']._serialized_start=12192
  _globals['_DELETESUBNETREQUEST']._serialized_end=12312
  _globals['_UPDATESUBNETREQUEST']._serialized_start=12315
  _globals['_UPDATESUBNETREQUEST']._serialized_end=12523
  _globals['_LISTSUBNETSREQUEST']._serialized_start=12526
  _globals['_LISTSUBNETSREQUEST']._serialized_end=12672
  _globals['_LISTSUBNETSRESPONSE']._serialized_start=12674
  _globals['_LISTSUBNETSRESPONSE']._serialized_end=12799
  _globals['_GETSUBNETREQUEST']._serialized_start=12801
  _globals['_GETSUBNETREQUEST']._serialized_end=12881
  _globals['_CREATETUNNELREQUEST']._serialized_start=12884
  _globals['_CREATETUNNELREQUEST']._serialized_end=13070
  _globals['_DELETETUNNELREQUEST']._serialized_start=13072
  _globals['_DELETETUNNELREQUEST']._serialized_end=13192
  _globals['_UPDATETUNNELREQUEST']._serialized_start=13195
  _globals['_UPDATETUNNELREQUEST']._serialized_end=13403
  _globals['_LISTTUNNELSREQUEST']._serialized_start=13406
  _globals['_LISTTUNNELSREQUEST']._serialized_end=13552
  _globals['_LISTTUNNELSRESPONSE']._serialized_start=13554
  _globals['_LISTTUNNELSRESPONSE']._serialized_end=13679
  _globals['_GETTUNNELREQUEST']._serialized_start=13681
  _globals['_GETTUNNELREQUEST']._serialized_end=13761
  _globals['_CREATEVPCREQUEST']._serialized_start=13764
  _globals['_CREATEVPCREQUEST']._serialized_end=13929
  _globals['_DELETEVPCREQUEST']._serialized_start=13931
  _globals['_DELETEVPCREQUEST']._serialized_end=14045
  _globals['_UPDATEVPCREQUEST']._serialized_start=14048
  _globals['_UPDATEVPCREQUEST']._serialized_end=14241
  _globals['_LISTVPCSREQUEST']._serialized_start=14244
  _globals['_LISTVPCSREQUEST']._serialized_end=14384
  _globals['_LISTVPCSRESPONSE']._serialized_start=14386
  _globals['_LISTVPCSRESPONSE']._serialized_end=14499
  _globals['_GETVPCREQUEST']._serialized_start=14501
  _globals['_GETVPCREQUEST']._serialized_end=14575
  _globals['_CREATEVPCPEERREQUEST']._serialized_start=14578
  _globals['_CREATEVPCPEERREQUEST']._serialized_end=14771
  _globals['_DELETEVPCPEERREQUEST']._serialized_start=14773
  _globals['_DELETEVPCPEERREQUEST']._serialized_end=14895
  _globals['_UPDATEVPCPEERREQUEST']._serialized_start=14898
  _globals['_UPDATEVPCPEERREQUEST']._serialized_end=15111
  _globals['_LISTVPCPEERSREQUEST']._serialized_start=15114
  _globals['_LISTVPCPEERSREQUEST']._serialized_end=15262
  _globals['_LISTVPCPEERSRESPONSE']._serialized_start=15265
  _globals['_LISTVPCPEERSRESPONSE']._serialized_end=15394
  _globals['_GETVPCPEERREQUEST']._serialized_start=15396
  _globals['_GETVPCPEERREQUEST']._serialized_end=15478
  _globals['_CREATESECURITYPOLICYREQUEST']._serialized_start=15481
  _globals['_CREATESECURITYPOLICYREQUEST']._serialized_end=15723
  _globals['_DELETESECURITYPOLICYREQUEST']._serialized_start=15726
  _globals['_DELETESECURITYPOLICYREQUEST']._serialized_end=15862
  _globals['_UPDATESECURITYPOLICYREQUEST']._serialized_start=15865
  _globals['_UPDATESECURITYPOLICYREQUEST']._serialized_end=16113
  _globals['_LISTSECURITYPOLICYSREQUEST']._serialized_start=16116
  _globals['_LISTSECURITYPOLICYSREQUEST']._serialized_end=16278
  _globals['_LISTSECURITYPOLICYSRESPONSE']._serialized_start=16281
  _globals['_LISTSECURITYPOLICYSRESPONSE']._serialized_end=16438
  _globals['_GETSECURITYPOLICYREQUEST']._serialized_start=16440
  _globals['_GETSECURITYPOLICYREQUEST']._serialized_end=16536
  _globals['_CREATESECURITYRULEREQUEST']._serialized_start=16539
  _globals['_CREATESECURITYRULEREQUEST']._serialized_end=16767
  _globals['_DELETESECURITYRULEREQUEST']._serialized_start=16770
  _globals['_DELETESECURITYRULEREQUEST']._serialized_end=16902
  _globals['_UPDATESECURITYRULEREQUEST']._serialized_start=16905
  _globals['_UPDATESECURITYRULEREQUEST']._serialized_end=17143
  _globals['_LISTSECURITYRULESREQUEST']._serialized_start=17146
  _globals['_LISTSECURITYRULESREQUEST']._serialized_end=17304
  _globals['_LISTSECURITYRULESRESPONSE']._serialized_start=17307
  _globals['_LISTSECURITYRULESRESPONSE']._serialized_end=17456
  _globals['_GETSECURITYRULEREQUEST']._serialized_start=17458
  _globals['_GETSECURITYRULEREQUEST']._serialized_end=17550
  _globals['_CREATESECURITYPROFILEREQUEST']._serialized_start=17553
  _globals['_CREATESECURITYPROFILEREQUEST']._serialized_end=17802
  _globals['_DELETESECURITYPROFILEREQUEST']._serialized_start=17805
  _globals['_DELETESECURITYPROFILEREQUEST']._serialized_end=17943
  _globals['_UPDATESECURITYPROFILEREQUEST']._serialized_start=17946
  _globals['_UPDATESECURITYPROFILEREQUEST']._serialized_end=18199
  _globals['_LISTSECURITYPROFILESREQUEST']._serialized_start=18202
  _globals['_LISTSECURITYPROFILESREQUEST']._serialized_end=18366
  _globals['_LISTSECURITYPROFILESRESPONSE']._serialized_start=18369
  _globals['_LISTSECURITYPROFILESRESPONSE']._serialized_end=18530
  _globals['_GETSECURITYPROFILEREQUEST']._serialized_start=18532
  _globals['_GETSECURITYPROFILEREQUEST']._serialized_end=18630
  _globals['_CLOUDINFRASERVICE']._serialized_start=18633
  _globals['_CLOUDINFRASERVICE']._serialized_end=34387
# @@protoc_insertion_point(module_scope)
